@@ -168,12 +168,32 @@ static void reinit_child(struct childdata *child)
 	child->dontkillme = FALSE;
 }
 
+static void bind_child_to_cpu(struct childdata *child)
+{
+	cpu_set_t set;
+	unsigned int cpudest;
+
+	if (no_bind_to_cpu == TRUE)
+		return;
+
+	if (sched_getaffinity(child->pid, sizeof(set), &set) != 0)
+		return;
+
+	if (child->num > num_online_cpus)
+		cpudest = child->num % num_online_cpus;
+	else
+		cpudest = child->num;
+
+	CPU_ZERO(&set);
+	CPU_SET(cpudest, &set);
+	sched_setaffinity(child->pid, sizeof(set), &set);
+}
+
 /*
  * Called from the fork_children loop in the main process.
  */
 void init_child(struct childdata *child, int childno)
 {
-	cpu_set_t set;
 	pid_t pid = getpid();
 	char childname[17];
 
@@ -196,7 +216,7 @@ void init_child(struct childdata *child, int childno)
 
 	reinit_child(child);
 
-	open_child_logfile(child);
+	init_child_logging(child);
 
 	set_seed(this_child);
 
@@ -204,11 +224,8 @@ void init_child(struct childdata *child, int childno)
 
 	dirty_random_mapping();
 
-	if (sched_getaffinity(pid, sizeof(set), &set) == 0) {
-		CPU_ZERO(&set);
-		CPU_SET(childno, &set);
-		sched_setaffinity(pid, sizeof(set), &set);
-	}
+	if (RAND_BOOL())
+		bind_child_to_cpu(child);
 
 	memset(childname, 0, sizeof(childname));
 	sprintf(childname, "trinity-c%d", childno);
@@ -222,7 +239,7 @@ void init_child(struct childdata *child, int childno)
 
 	set_make_it_fail();
 
-	if (rand_bool())
+	if (RAND_BOOL())
 		use_fpu();
 
 	mask_signals_child();
@@ -360,7 +377,6 @@ static bool handle_sigreturn(void)
  */
 void child_process(void)
 {
-	const char *lastop = NULL;
 	int ret;
 
 	ret = sigsetjmp(ret_jump, 1);
@@ -369,6 +385,8 @@ void child_process(void)
 			return;	// Exit the child, things are getting too weird.
 	}
 
+	shm_rw();
+
 	while (shm->exit_reason == STILL_RUNNING) {
 		unsigned int i;
 
@@ -382,6 +400,8 @@ void child_process(void)
 		i = rand() % ARRAY_SIZE(child_ops);
 
 		if (rand() % 100 <= child_ops[i].likelyhood) {
+			const char *lastop = NULL;
+
 			if (lastop != child_ops[i].name) {
 				//output(0, "Chose %s.\n", child_ops[i].name);
 				lastop = child_ops[i].name;
