@@ -9,9 +9,9 @@
 
 #include "arch.h"	// biarch
 #include "child.h"
+#include "debug.h"
 #include "locks.h"
 #include "log.h"
-#include "params.h"	// dopause
 #include "pids.h"
 #include "random.h"
 #include "shm.h"
@@ -50,7 +50,7 @@ static bool choose_syscall_table(void)
 		/* If both tables enabled, pick randomly. */
 		if ((use_64bit == TRUE) && (use_32bit == TRUE)) {
 			/* 10% possibility of a 32bit syscall */
-			if (rand() % 100 < 10)
+			if (ONE_IN(10))
 				do32 = TRUE;
 		}
 
@@ -73,6 +73,9 @@ bool child_random_syscalls(void)
 	unsigned int syscallnr;
 	bool do32;
 	unsigned int len;
+	unsigned long a1, a2, a3;
+	time_t old;
+	pid_t oldpid;
 
 retry:
 	if (no_syscalls_enabled() == TRUE) {
@@ -112,6 +115,12 @@ retry:
 	/* Generate arguments, print them out */
 
 	generate_syscall_args(rec);
+
+	a1 = rec->a1;
+	a2 = rec->a2;
+	a3 = rec->a3;
+	oldpid = this_child->pid;
+
 	output_syscall_prefix(rec);
 
 	/* Sanity check: Make sure the length of the buffer remains
@@ -119,24 +128,45 @@ retry:
 	 */
 	len = strlen(rec->prebuffer);
 
-	/* If we're going to pause, might as well sync pre-syscall */
-	if (dopause == TRUE)
-		synclogs();
-
+	old = rec->tv.tv_sec;
 	do_syscall(rec);
 
+	if (this_child->pid == 0) {
+		output(0, "Sanity check failed. my pid became zero after syscall:%s(%lx, %lx, %lx)  was:%d\n",
+				print_syscall_name(syscallnr, do32),
+				a1, a2, a3, oldpid);
+			dump_childnos();
+			dump_childdata(this_child);
+			panic(EXIT_PID_OUT_OF_RANGE);
+	}
+
+	if (old != 0) {
+		// FIXME: Should factor in loadavg here, as with enough pids, a child can exceed 60s
+		//  without getting scheduled.
+		if (rec->tv.tv_sec - old > 60) {
+			output(0, "Sanity check failed. Something stomped on rec->tv after syscall:%s(%lx, %lx, %lx)  was:%lx now:%lx.\n",
+				print_syscall_name(syscallnr, do32),
+				a1, a2, a3, old, rec->tv.tv_sec);
+			dump_childnos();
+			dump_childdata(this_child);
+			panic(EXIT_PID_OUT_OF_RANGE);
+		}
+	}
+
 	/* post syscall sanity checks. */
 	if (len != strlen(rec->prebuffer)) {
-		output(0, "Sanity check failed: prebuffer length changed from %d to %d.\n",
-			len, strlen(rec->prebuffer));
+		output(0, "Sanity check failed: prebuffer length changed from %d to %d after syscall:%s(%lx, %lx, %lx).\n",
+			len, strlen(rec->prebuffer),
+			print_syscall_name(syscallnr, do32),
+			a1, a2, a3);
+		dump_childnos();
+		dump_childdata(this_child);
+		panic(EXIT_PID_OUT_OF_RANGE);
 	}
 
 	/* Output the syscall result, and clean up */
 	output_syscall_postfix(rec);
 
-	if (dopause == TRUE)
-		sleep(1);
-
 	handle_syscall_ret(rec);
 
 	return TRUE;
