@@ -256,6 +256,15 @@ enum {
 #define NETLINK_RX_RING 6
 #define NETLINK_TX_RING 7
 #endif
+#ifndef NETLINK_LISTEN_ALL_NSID
+#define NETLINK_LISTEN_ALL_NSID 8
+#endif
+#ifndef NETLINK_LIST_MEMBERSHIPS
+#define NETLINK_LIST_MEMBERSHIPS 9
+#endif
+#ifndef NETLINK_CAP_ACK
+#define NETLINK_CAP_ACK 10
+#endif
 
 /* linux/prctl.h */
 #ifndef PR_MCE_KILL_GET
@@ -269,8 +278,14 @@ enum {
 #ifndef PR_SET_CHILD_SUBREAPER
 #define PR_SET_CHILD_SUBREAPER  36
 #define PR_GET_CHILD_SUBREAPER  37
+#endif
+
+#ifndef PR_SET_NO_NEW_PRIVS
 #define PR_SET_NO_NEW_PRIVS     38
 #define PR_GET_NO_NEW_PRIVS     39
+#endif
+
+#ifndef PR_GET_TID_ADDRESS
 #define PR_GET_TID_ADDRESS      40
 #endif
 
@@ -284,6 +299,18 @@ enum {
 #define PR_MPX_DISABLE_MANAGEMENT 44
 #endif
 
+#ifdef __mips__
+#ifndef PR_SET_FP_MODE
+#define PR_SET_FP_MODE         45
+#define PR_GET_FP_MODE         46
+#endif
+#endif
+
+#ifndef PR_CAP_AMBIENT
+#define PR_CAP_AMBIENT		47
+#endif
+
+
 /* linux/rds.h */
 #ifndef RDS_CANCEL_SENT_TO
 #define RDS_CANCEL_SENT_TO              1
@@ -446,6 +473,23 @@ enum kcmp_type {
 #define TCP_FASTOPEN		23
 #endif
 
+#ifndef TCP_TIMESTAMP
+#define TCP_TIMESTAMP		24
+#endif
+
+#ifndef TCP_NOTSENT_LOWAT
+#define TCP_NOTSENT_LOWAT	25
+#endif
+
+#ifndef TCP_CC_INFO
+#define TCP_CC_INFO		26
+#endif
+
+#ifndef TCP_SAVE_SYN
+#define TCP_SAVE_SYN		27
+#define TCP_SAVED_SYN		28
+#endif
+
 /* linux/if_packet.h */
 #ifndef PACKET_VNET_HDR
 #define PACKET_VNET_HDR		15
@@ -511,6 +555,12 @@ enum kcmp_type {
 #ifndef IP_NODEFRAG
 #define IP_NODEFRAG		22
 #endif
+#ifndef IP_CHECKSUM
+#define IP_CHECKSUM		23
+#endif
+#ifndef IP_BIND_ADDRESS_NO_PORT
+#define IP_BIND_ADDRESS_NO_PORT	24
+#endif
 #ifndef IP_MULTICAST_ALL
 #define IP_MULTICAST_ALL	49
 #endif
@@ -520,12 +570,47 @@ enum kcmp_type {
 #ifndef IPPROTO_BEETPH
 #define IPPROTO_BEETPH		94
 #endif
+#ifndef IPPROTO_MPLS
+#define IPPROTO_MPLS		137
+#endif
 
 /* linux/in6.h */
 #ifndef IPV6_FLOWINFO
 #define IPV6_FLOWINFO 11
 #endif
 
+#ifndef IPV6_FLOWLABEL_MGR
+#define IPV6_FLOWLABEL_MGR      32
+#define IPV6_FLOWINFO_SEND      33
+#endif
+
+#ifndef IPV6_RECVPATHMTU
+#define IPV6_RECVPATHMTU        60
+#define IPV6_PATHMTU            61
+#define IPV6_DONTFRAG           62
+#endif
+
+#ifndef IP6T_SO_GET_REVISION_MATCH
+#define IP6T_SO_GET_REVISION_MATCH   68
+#define IP6T_SO_GET_REVISION_TARGET  69
+#define IP6T_SO_ORIGINAL_DST         80
+#endif
+
+#ifndef IPV6_AUTOFLOWLABEL
+#define IPV6_AUTOFLOWLABEL      70
+#define IPV6_ADDR_PREFERENCES   72
+#endif
+
+#ifndef IPV6_MINHOPCOUNT
+#define IPV6_MINHOPCOUNT        73
+#define IPV6_ORIGDSTADDR        74
+#define IPV6_RECVORIGDSTADDR    IPV6_ORIGDSTADDR
+#define IPV6_TRANSPARENT        75
+#define IPV6_UNICAST_IF         76
+#endif
+
+
+
 /* asm/resource.h */
 #ifndef RLIMIT_RTTIME
 #define RLIMIT_RTTIME		15
@@ -945,3 +1030,19 @@ struct kvm_get_htab_fd {
 #ifndef EPOLLWAKEUP
 #define EPOLLWAKEUP (1u << 29)
 #endif
+
+/* time.h */
+#ifndef CLOCK_MONOTONIC_RAW
+#define CLOCK_MONOTONIC_RAW 4
+#endif
+#ifndef CLOCK_BOOTTIME
+#define CLOCK_BOOTTIME 7
+#endif
+
+/* asm-generic/poll.h */
+#ifndef POLLFREE
+#define POLLFREE 0x4000
+#endif
+#ifndef POLL_BUSY_LOOP
+#define POLL_BUSY_LOOP 0x8000
+#endif
