@@ -1,5 +1,4 @@
-#ifndef __LIST_H__
-#define __LIST_H__
+#pragma once
 
 #include <stdio.h>
 
@@ -54,7 +53,32 @@ static inline void list_del(struct list_head *entry)
         entry->next = entry->prev = NULL;
 }
 
+static inline void __list_del_entry(struct list_head *entry)
+{
+	__list_del(entry->prev, entry->next);
+}
+
+/**
+ * list_move - delete from one list and add as another's head
+ * @list: the entry to move
+ * @head: the head that will precede our entry
+ */
+static inline void list_move(struct list_head *list, struct list_head *head)
+{
+	__list_del_entry(list);
+	list_add(list, head);
+}
+
 #define list_for_each(pos, head) \
          for (pos = (head)->next; pos != (head); pos = pos->next)
 
-#endif
+/**
+ * list_for_each_safe - iterate over a list safe against removal of list entry
+ * @pos:        the &struct list_head to use as a loop cursor.
+ * @n:          another &struct list_head to use as temporary storage
+ * @head:       the head for your list.
+ */
+#define list_for_each_safe(pos, n, head) \
+	for (pos = (head)->next, n = pos->next; pos != (head); \
+		pos = n, n = pos->next)
+
