@@ -31,6 +31,11 @@ struct socket_triplet {
 	unsigned int protocol;
 };
 
+struct sock_option {
+	unsigned int name;
+	unsigned int len;
+};
+
 struct sockopt {
 	unsigned int level;
 	unsigned long optname;
@@ -48,9 +53,13 @@ void close_sockets(void);
 
 const struct fd_provider socket_fd_provider;
 
+struct socketinfo * get_rand_socketinfo(void);
+int generic_fd_from_socketinfo(struct socketinfo *si);
+
 void generate_sockaddr(struct sockaddr **addr, socklen_t *addrlen, int pf);
 
-void do_setsockopt(struct sockopt *so);
+unsigned int sockoptlen(unsigned int len);
+void do_setsockopt(struct sockopt *so, struct socket_triplet *triplet);
 
 void rand_proto_type(struct socket_triplet *st);
 int sanitise_socket_triplet(struct socket_triplet *st);
@@ -89,12 +98,10 @@ void caif_setsockopt(struct sockopt *so);
 
 /* alg */
 void alg_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen);
-void alg_setsockopt(struct sockopt *so);
 
 /* nfc */
 void nfc_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen);
 void nfc_rand_socket(struct socket_triplet *st);
-void nfc_setsockopt(struct sockopt *so);
 
 /* ax25 */
 void ax25_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen);
@@ -109,7 +116,6 @@ void ipx_setsockopt(struct sockopt *so);
 /* appletalk */
 void atalk_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen);
 void atalk_rand_socket(struct socket_triplet *st);
-void atalk_setsockopt(struct sockopt *so);
 
 /* atm */
 void atmpvc_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen);
@@ -180,10 +186,34 @@ void icmpv6_setsockopt(struct sockopt *so);
 void sctp_setsockopt(struct sockopt *so);
 void raw_setsockopt(struct sockopt *so);
 void netrom_setsockopt(struct sockopt *so);
-void aal_setsockopt(struct sockopt *so);
-void netbeui_setsockopt(struct sockopt *so);
 void dccp_setsockopt(struct sockopt *so);
 void rxrpc_setsockopt(struct sockopt *so);
 void bluetooth_setsockopt(struct sockopt *so);
-void pnpipe_setsockopt(struct sockopt *so);
 void iucv_setsockopt(struct sockopt *so);
+
+/* protocol definitions */
+#define SOL_TCP 6
+#define SOL_SCTP 132
+#define SOL_UDPLITE 136
+#define SOL_NETBEUI 267
+#define SOL_LLC 268
+#define SOL_DCCP 269
+#define SOL_NETLINK 270
+#define SOL_RXRPC 272
+#define SOL_PPPOL2TP 273
+#define SOL_BLUETOOTH 274
+#define SOL_PNPIPE 275
+#define SOL_RDS 276
+#define SOL_IUCV 277
+#define SOL_CAIF 278
+#define SOL_ALG 279
+#define SOL_NFC 280
+
+#ifndef AF_IB
+#define AF_IB 27
+#define PF_IB 27
+#endif
+#ifndef AF_MPLS
+#define AF_MPLS 28
+#define PF_MPLS 28
+#endif
