@@ -31,7 +31,7 @@ extern unsigned int specific_domain;
 extern bool do_specific_domain;
 extern char *specific_domain_optarg;
 extern bool no_domains[TRINITY_PF_MAX];
-extern bool dopause;
+extern bool dry_run;
 extern bool show_syscall_list;
 extern bool show_ioctl_list;
 extern unsigned char quiet_level;
@@ -40,7 +40,7 @@ extern bool monochrome;
 extern bool dangerous;
 extern bool dropprivs;
 extern bool do_syslog;
-extern bool logging;
+extern int logging;
 extern unsigned char desired_group;
 extern bool user_set_seed;
 extern char *victim_path;
