@@ -2,10 +2,12 @@
 
 #include "arch.h"
 #include "child.h"
+#include "drm_fds.h"
 #include "epoll.h"
 #include "eventfd.h"
 #include "exit.h"
 #include "files.h"
+#include "inotify.h"
 #include "locks.h"
 #include "memfd.h"
 #include "net.h"
@@ -20,6 +22,9 @@
 void create_shm(void);
 void init_shm(void);
 
+void shm_ro(void);
+void shm_rw(void);
+
 struct shm_s {
 	struct childdata **children;
 
@@ -61,6 +66,8 @@ struct shm_s {
 	int timerfd_fds[MAX_TIMERFD_FDS];
 	int testfile_fds[MAX_TESTFILE_FDS];
 	int memfd_fds[MAX_MEMFD_FDS];
+	int drm_fds[MAX_DRM_FDS];
+	int inotify_fds[MAX_INOTIFY_FDS];
 	struct socketinfo sockets[NR_SOCKET_FDS];
 	int current_fd;
 	unsigned int fd_lifetime;
