@@ -1,10 +1,9 @@
-#ifndef _SIGNALS_H
-#define _SIGNALS_H 1
+#pragma once
 
 #include <setjmp.h>
 
+extern int sigwas;
 extern jmp_buf ret_jump;
+
 void mask_signals_child(void);
 void setup_main_signals(void);
-
-#endif	/* _SIGNALS_H */
