@@ -366,4 +366,20 @@ struct syscalltable syscalls_i386[] = {
 	{ .entry = &syscall_memfd_create },
 	{ .entry = &syscall_bpf },
 	{ .entry = &syscall_execveat },
+	{ .entry = &syscall_socket },
+	{ .entry = &syscall_socketpair },
+	{ .entry = &syscall_bind },
+	{ .entry = &syscall_connect },
+	{ .entry = &syscall_listen },
+	{ .entry = &syscall_accept4 },
+	{ .entry = &syscall_getsockopt },
+	{ .entry = &syscall_setsockopt },
+	{ .entry = &syscall_getsockname },
+	{ .entry = &syscall_getpeername },
+	{ .entry = &syscall_sendto },
+	{ .entry = &syscall_sendmsg },
+	{ .entry = &syscall_recvfrom },
+	{ .entry = &syscall_recvmsg },
+	{ .entry = &syscall_shutdown },
+	{ .entry = &syscall_userfaultfd },
 };
