@@ -275,9 +275,9 @@ struct syscalltable syscalls_s390[] = {
 	{ .entry = &syscall_statfs64 },
 	{ .entry = &syscall_fstatfs64 },
 	{ .entry = &syscall_remap_file_pages },
-	{ .entry = &syscall_ni_syscall },
-	{ .entry = &syscall_ni_syscall },
-	{ .entry = &syscall_ni_syscall },
+	{ .entry = &syscall_mbind },
+	{ .entry = &syscall_get_mempolicy },
+	{ .entry = &syscall_set_mempolicy },
 	{ .entry = &syscall_mq_open },
 	{ .entry = &syscall_mq_unlink },
 	{ .entry = &syscall_mq_timedsend },
@@ -294,7 +294,7 @@ struct syscalltable syscalls_s390[] = {
 	{ .entry = &syscall_inotify_init },
 	{ .entry = &syscall_inotify_add_watch },
 	{ .entry = &syscall_inotify_rm_watch },
-	{ .entry = &syscall_ni_syscall },
+	{ .entry = &syscall_migrate_pages },
 	{ .entry = &syscall_openat },
 	{ .entry = &syscall_mkdirat },
 	{ .entry = &syscall_mknodat },
@@ -317,7 +317,7 @@ struct syscalltable syscalls_s390[] = {
 	{ .entry = &syscall_sync_file_range },
 	{ .entry = &syscall_tee },
 	{ .entry = &syscall_vmsplice },
-	{ .entry = &syscall_ni_syscall },
+	{ .entry = &syscall_move_pages },
 	{ .entry = &syscall_getcpu },
 	{ .entry = &syscall_epoll_pwait },
 	{ .entry = &syscall_utimes },
@@ -361,4 +361,5 @@ struct syscalltable syscalls_s390[] = {
 	{ .entry = &syscall_bpf },
 	{ .entry = &syscall_ni_syscall },	// TODO: syscall_s390_pci_mmio_write
 	{ .entry = &syscall_ni_syscall },	// TODO: syscall_s390_pci_mmio_read
+	{ .entry = &syscall_execveat },
 };
