@@ -1,3 +1,5 @@
+#pragma once
+
 #include "sanitise.h"
 #include "syscall.h"
 #include "syscalls/syscalls.h"
@@ -393,6 +395,7 @@ struct syscalltable syscalls_sh[] = {
 	{ .entry = &syscall_process_vm_readv },
 	{ .entry = &syscall_process_vm_writev },
 	{ .entry = &syscall_kcmp },
+	{ .entry = &syscall_finit_module },
 };
 #else
 
@@ -767,5 +770,5 @@ struct syscalltable syscalls_sh[] = {
 	{ .entry = &syscall_process_vm_readv },	/* 365 */
 	{ .entry = &syscall_process_vm_writev },
 	{ .entry = &syscall_kcmp },
+	{ .entry = &syscall_finit_module },
 };
-#endif
