@@ -1,9 +1,9 @@
 #pragma once
 
-#include "child.h"
-#include "syscall.h"
+#include "types.h"
 
 extern unsigned int num_online_cpus;
+extern bool no_bind_to_cpu;
 
 extern char *progname;
 
@@ -11,7 +11,6 @@ void main_loop(void);
 void exit_main_fail(void);
 
 void init_watchdog(void);
-unsigned int check_if_fd(struct childdata *child, struct syscallrecord *rec);
 
 void panic(int reason);
 
