@@ -1,5 +1,4 @@
-#ifndef _TYPES_H
-#define _TYPES_H 1
+#pragma once
 
 #include <sys/types.h>
 
@@ -7,5 +6,3 @@ typedef enum { FALSE = 0, TRUE = 1 } bool;
 
 typedef __uint32_t u32;
 typedef __uint64_t u64;
-
-#endif	/* _TYPES_H */
