@@ -5,8 +5,8 @@
 #include <stdio.h>
 #include <string.h>
 
-#define MB (1024 * 1024UL)
-#define GB (1024 * MB)
+#define MB(_x) (_x * 1024UL * 1024UL)
+#define GB(_x) (_x * 1024UL * MB(1))
 
 void * alloc_shared(unsigned int size);
 
@@ -54,3 +54,8 @@ void freeptr(unsigned long *p);
 #define __stringify(x...)       __stringify_1(x)
 
 #define unreachable() do { } while (1)
+
+#define RAND_ELEMENT(_array, _element) \
+	_array[rand() % ARRAY_SIZE(_array)]._element
+
+#define RAND_ARRAY(_array) _array[rand() % ARRAY_SIZE(_array)]
