@@ -1,16 +1,10 @@
-#include <errno.h>
 #include <stdio.h>
-#include <stdlib.h>
 #include <stdarg.h>
-#include <string.h>
-#include <unistd.h>
-#include <fcntl.h>
 #include "log.h"
 #include "params.h"	// logging, monochrome, quiet_level
 #include "pids.h"
 #include "shm.h"
 #include "trinity.h"
-#include "utils.h"
 
 #define BUFSIZE 1024	// decoded syscall args are fprintf'd directly, this is for everything else.
 
@@ -23,156 +17,6 @@ char ANSI_CYAN[] = "[1;36m";
 char ANSI_WHITE[] = "[1;37m";
 char ANSI_RESET[] = "[0m";
 
-FILE *mainlogfile;
-
-static bool logfiles_opened = FALSE;
-
-static FILE *open_logfile(const char *logfilename)
-{
-	FILE *file;
-
-	unlink(logfilename);
-
-	file = fopen(logfilename, "w");
-	if (!file)
-		outputerr("## couldn't open logfile %s\n", logfilename);
-
-	return file;
-}
-
-void open_main_logfile(void)
-{
-	mainlogfile = open_logfile("trinity.log");
-	if (!mainlogfile)
-		exit(EXIT_FAILURE);
-
-	logfiles_opened = TRUE;	//FIXME: This is a bit crap
-}
-
-void open_child_logfile(struct childdata *child)
-{
-	char *logfilename;
-
-	if (logging == FALSE)
-		return;
-
-	logfilename = zmalloc(64);
-	sprintf(logfilename, "trinity-child%u.log", child->num);
-
-	child->logfile = open_logfile(logfilename);
-	if (!child->logfile) {
-		shm->exit_reason = EXIT_LOGFILE_OPEN_ERROR;
-		exit(EXIT_FAILURE);
-	}
-
-	free(logfilename);
-
-	child->logdirty = FALSE;
-}
-
-void close_logfile(FILE **filehandle)
-{
-	if (*filehandle == NULL)
-		return;
-
-	fclose(*filehandle);
-	*filehandle = NULL;
-}
-
-static FILE * find_child_logfile_handle(pid_t pid)
-{
-	int i;
-	unsigned int j;
-	FILE *log = NULL;
-
-	i = find_childno(pid);
-	if (i != CHILD_NOT_FOUND) {
-		log = shm->children[i]->logfile;
-	} else {
-		/* This is pretty ugly, and should never happen,
-		 * but try again a second later, in case we're racing setup/teardown.
-		 * FIXME: We may not even need this now that we have proper locking; test it.
-		 */
-		sleep(1);
-		i = find_childno(pid);
-		if (i == CHILD_NOT_FOUND) {
-			outputerr("Couldn't find child for pid %d\n", pid);
-			return mainlogfile;
-		}
-		log = shm->children[i]->logfile;
-
-	}
-
-	if (log != NULL)
-		return log;
-
-	/* if the logfile hadn't been set, log to main. */
-	shm->children[i]->logfile = mainlogfile;
-	outputerr("## child %d logfile handle was null logging to main!\n", i);
-
-	outputerr("## Couldn't find logfile for pid %d\n", pid);
-	dump_childnos();
-	outputerr("## Logfiles for pids: ");
-	for_each_child(j)
-		outputerr("%p ", shm->children[j]->logfile);
-	outputerr("\n");
-
-	(void)fflush(stdout);
-
-	sleep(5);
-	return mainlogfile;
-}
-
-FILE *find_logfile_handle(void)
-{
-	FILE *handle = NULL;
-
-	if ((logging == TRUE) && (logfiles_opened)) {
-		pid_t pid;
-
-		pid = getpid();
-		if (pid == initpid)
-			return mainlogfile;
-
-		if (pid == shm->mainpid)
-			return mainlogfile;
-
-		if (pid == watchdog_pid)
-			return mainlogfile;
-
-		handle = find_child_logfile_handle(pid);
-	}
-	return handle;
-}
-
-/*
- * Flush any pending log writes to disk.
- * Only to be called from child context.
- */
-void synclogs(void)
-{
-	int fd;
-
-	if (logging == FALSE)
-		return;
-
-	if (this_child->logdirty == FALSE)
-		return;
-
-	fflush(this_child->logfile);
-	fd = fileno(this_child->logfile);
-	if (fd != -1)
-		(void) fsync(fd);
-
-	this_child->logdirty = FALSE;
-
-	/* If we're flushing the child log, may as well flush
-	 * any other logs while we're writing to disk.
-	 */
-	(void)fflush(mainlogfile);
-	fsync(fileno(mainlogfile));
-}
-
 void strip_ansi(char *ansibuf)
 {
 	char *from = ansibuf, *to = ansibuf;
@@ -228,7 +72,7 @@ void output(unsigned char level, const char *fmt, ...)
 	char main_prefix[]="[main]";
 	char child_prefix[32];
 
-	if (logging == FALSE && level >= quiet_level)
+	if (logging == LOGGING_DISABLED && level >= quiet_level)
 		return;
 
 	/* prefix preparation */
@@ -270,7 +114,7 @@ void output(unsigned char level, const char *fmt, ...)
 	}
 
 	/* go on with file logs only if enabled */
-	if (logging == FALSE)
+	if (logging == LOGGING_FILES)
 		return;
 
 	handle = find_logfile_handle();
@@ -305,3 +149,71 @@ void outputstd(const char *fmt, ...)
 	vfprintf(stdout, fmt, args);
 	va_end(args);
 }
+
+
+// TODO: combine the below with output()
+void output_rendered_buffer(char *buffer)
+{
+	FILE *log_handle;
+
+	/* Output to stdout only if -q param is not specified */
+	if (quiet_level == MAX_LOGLEVEL) {
+		fprintf(stdout, "%s", buffer);
+		fflush(stdout);
+	}
+
+	/* Exit if should not continue at all. */
+	if (logging == LOGGING_DISABLED)
+		return;
+
+	log_handle = find_logfile_handle();
+	if (log_handle != NULL) {
+		strip_ansi(buffer);
+		fprintf(log_handle, "%s", buffer);
+		fflush(log_handle);
+	}
+}
+
+void init_logging(void)
+{
+	switch (logging) {
+	case LOGGING_DISABLED:
+		return;
+	case LOGGING_FILES:
+		open_main_logfile();
+		return;
+	}
+}
+
+void shutdown_logging(void)
+{
+	switch (logging) {
+	case LOGGING_DISABLED:
+		return;
+	case LOGGING_FILES:
+		close_logfile(&mainlogfile);
+		return;
+	}
+}
+
+void init_child_logging(struct childdata *child)
+{
+	switch (logging) {
+	case LOGGING_DISABLED:
+		return;
+	case LOGGING_FILES:
+		open_child_logfile(child);
+		return;
+	}
+}
+
+void shutdown_child_logging(struct childdata *child)
+{
+	switch (logging) {
+	case LOGGING_DISABLED:
+		return;
+	case LOGGING_FILES:
+		close_logfile(&child->logfile);
+		return;
+	}
+}
