@@ -70,7 +70,7 @@ static void fork_children(void)
 			child_process();
 
 			debugf("child %d %d exiting.\n", childno, getpid());
-			close_logfile(&this_child->logfile);
+			shutdown_child_logging(this_child);
 			reap_child(child->pid);
 			_exit(EXIT_SUCCESS);
 		} else {
@@ -174,6 +174,11 @@ static void handle_childsig(int childpid, int childstatus, int stop)
 		return;
 
 	default:
+		if (__sig >= SIGRTMIN) {
+			debugf("Child %d got RT signal (%d). Ignoring.\n", childpid, __sig);
+			return;
+		}
+
 		if (stop == TRUE)
 			debugf("Child %d was stopped by unhandled signal (%s).\n", childpid, strsignal(WSTOPSIG(childstatus)));
 		else
