@@ -7,7 +7,7 @@
 #include <netinet/in.h>
 #include <stdlib.h>
 #include "net.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
 void atmpvc_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
@@ -42,16 +42,15 @@ void atmsvc_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 	*addrlen = sizeof(struct sockaddr_atmsvc);
 }
 
-#define NR_SOL_ATM_OPTS ARRAY_SIZE(atm_opts)
+// TODO: If anyone gives a crap about ATM, we could do better
+// here and separate the pvc and svc ops.
+// Personally, I couldn't care less, so throw everything in the same array
+// just to make this simpler.
 static const unsigned int atm_opts[] = {
-	SO_SETCLP, SO_CIRANGE, SO_ATMQOS, SO_ATMSAP, SO_ATMPVC, SO_MULTIPOINT };
+	SO_SETCLP, SO_CIRANGE, SO_ATMQOS, SO_ATMSAP, SO_ATMPVC, SO_MULTIPOINT,
+};
 
 void atm_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
-
-	so->level = SOL_ATM;
-
-	val = rand() % NR_SOL_ATM_OPTS;
-	so->optname = atm_opts[val];
+	so->optname = RAND_ARRAY(atm_opts);
 }
