@@ -6,7 +6,7 @@
 #include <netax25/ax25.h>
 #include "net.h"
 #include "random.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
 void ax25_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
@@ -54,19 +54,14 @@ void ax25_rand_socket(struct socket_triplet *st)
 	}
 }
 
-#define NR_SOL_AX25_OPTS ARRAY_SIZE(ax25_opts)
 static const unsigned int ax25_opts[] = {
 	AX25_WINDOW, AX25_T1, AX25_N2, AX25_T3,
 	AX25_T2, AX25_BACKOFF, AX25_EXTSEQ, AX25_PIDINCL,
 	AX25_IDLE, AX25_PACLEN, AX25_IAMDIGI,
-	SO_BINDTODEVICE };
+	SO_BINDTODEVICE
+};
 
 void ax25_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
-
-	so->level = SOL_AX25;
-
-	val = rand() % NR_SOL_AX25_OPTS;
-	so->optname = ax25_opts[val];
+	so->optname = RAND_ARRAY(ax25_opts);
 }
