@@ -1,33 +1,26 @@
 #include <stdlib.h>
 #include "net.h"
 #include "compat.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 
-#define SOL_BLUETOOTH 274
-
-#define NR_SOL_BLUETOOTH_OPTS ARRAY_SIZE(bluetooth_opts)
 static const unsigned int bluetooth_opts[] = {
 	BT_SECURITY, BT_DEFER_SETUP, BT_FLUSHABLE, BT_POWER,
-	BT_CHANNEL_POLICY };
+	BT_CHANNEL_POLICY
+};
 
-#define NR_SOL_BLUETOOTH_HCI_OPTS ARRAY_SIZE(bluetooth_hci_opts)
 static const unsigned int bluetooth_hci_opts[] = {
-	HCI_DATA_DIR, HCI_FILTER, HCI_TIME_STAMP };
+	HCI_DATA_DIR, HCI_FILTER, HCI_TIME_STAMP
+};
 
-#define NR_SOL_BLUETOOTH_L2CAP_OPTS ARRAY_SIZE(bluetooth_l2cap_opts)
 static const unsigned int bluetooth_l2cap_opts[] = {
-	L2CAP_OPTIONS, L2CAP_LM };
+	L2CAP_OPTIONS, L2CAP_LM
+};
 
-#define NR_SOL_BLUETOOTH_RFCOMM_OPTS ARRAY_SIZE(bluetooth_rfcomm_opts)
 static const unsigned int bluetooth_rfcomm_opts[] = { RFCOMM_LM };
 
 
 void bluetooth_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
-
-	so->level = SOL_BLUETOOTH;
-
 	switch(rand() % 5) {
 	case 0: so->level = SOL_HCI; break;
 	case 1: so->level = SOL_L2CAP; break;
@@ -41,26 +34,22 @@ void bluetooth_setsockopt(struct sockopt *so)
 
 	switch (so->level) {
 	case SOL_HCI:
-		val = rand() % NR_SOL_BLUETOOTH_HCI_OPTS;
-		so->optname = bluetooth_hci_opts[val];
+		so->optname = RAND_ARRAY(bluetooth_hci_opts);
 		break;
 
 	case SOL_L2CAP:
-		val = rand() % NR_SOL_BLUETOOTH_L2CAP_OPTS;
-		so->optname = bluetooth_l2cap_opts[val];
+		so->optname = RAND_ARRAY(bluetooth_l2cap_opts);
 		break;
 
 	case SOL_SCO:   /* no options currently */
 		break;
 
 	case SOL_RFCOMM:
-		val = rand() % NR_SOL_BLUETOOTH_RFCOMM_OPTS;
-		so->optname = bluetooth_rfcomm_opts[val];
+		so->optname = RAND_ARRAY(bluetooth_rfcomm_opts);
 		break;
 
 	case SOL_BLUETOOTH:
-		val = rand() % NR_SOL_BLUETOOTH_OPTS;
-		so->optname = bluetooth_opts[val];
+		so->optname = RAND_ARRAY(bluetooth_opts);
 		break;
 
 	default: break;
