@@ -6,11 +6,9 @@
 #include "config.h"
 #include "net.h"
 #include "random.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
-#define SOL_CAIF 278
-
 #ifdef USE_CAIF
 #include <linux/caif/caif_socket.h>
 
@@ -39,28 +37,23 @@ void caif_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 void caif_rand_socket(struct socket_triplet *st)
 {
 	st->protocol = rand() % _CAIFPROTO_MAX;
-	if (rand_bool())
+	if (RAND_BOOL())
 		st->type = SOCK_SEQPACKET;
 	else
 		st->type = SOCK_STREAM;
 }
 
-static const unsigned int caif_opts[] = { CAIFSO_LINK_SELECT, CAIFSO_REQ_PARAM };
-#define NR_SOL_CAIF_OPTS ARRAY_SIZE(caif_opts)
+static const unsigned int caif_opts[] = {
+	CAIFSO_LINK_SELECT, CAIFSO_REQ_PARAM
+};
 
 void caif_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
-
-	so->level = SOL_CAIF;
-
-	val = rand() % NR_SOL_CAIF_OPTS;
-	so->optname = caif_opts[val];
+	so->optname = RAND_ARRAY(caif_opts);
 }
 #else
-/* stub if we are built on something without RDS headers */
+/* stub if we are built on something without CAIF headers */
 void caif_setsockopt(struct sockopt *so)
 {
-	so->level = SOL_CAIF;
 }
 #endif
