@@ -6,7 +6,7 @@
 #include <stdlib.h>
 #include "net.h"
 #include "random.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
 void decnet_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
@@ -22,7 +22,7 @@ void decnet_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 	dn->sdn_objnamel = rand() % 16;
 	for (i = 0; i < dn->sdn_objnamel; i++)
 		dn->sdn_objname[i] = rand();
-	dn->sdn_add.a_len = rand() % 2;
+	dn->sdn_add.a_len = RAND_BOOL();
 	dn->sdn_add.a_addr[0] = rand();
 	dn->sdn_add.a_addr[1] = rand();
 	*addr = (struct sockaddr *) dn;
@@ -31,7 +31,7 @@ void decnet_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 
 void decnet_rand_socket(struct socket_triplet *st)
 {
-	if (rand_bool()) {
+	if (RAND_BOOL()) {
 		st->type = SOCK_SEQPACKET;
 		st->protocol = DNPROTO_NSP;
 	} else {
@@ -40,7 +40,6 @@ void decnet_rand_socket(struct socket_triplet *st)
 	}
 }
 
-#define NR_SOL_DECNET_OPTS ARRAY_SIZE(decnet_opts)
 static const unsigned int decnet_opts[] = {
 	SO_CONDATA, SO_CONACCESS, SO_PROXYUSR, SO_LINKINFO,
 	DSO_CONDATA, DSO_DISDATA, DSO_CONACCESS, DSO_ACCEPTMODE,
@@ -51,13 +50,7 @@ static const unsigned int decnet_opts[] = {
 
 void decnet_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
-
-	so->level = SOL_DECNET;
-
-	val = rand() % NR_SOL_DECNET_OPTS;
-	so->optname = decnet_opts[val];
+	so->optname = RAND_ARRAY(decnet_opts);
 
 	// TODO: set optlen correctly
-
 }
