@@ -8,7 +8,7 @@
 #include <stdlib.h>
 #include "net.h"
 #include "random.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
 void irda_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
@@ -40,7 +40,7 @@ void irda_rand_socket(struct socket_triplet *st)
 		break;
 
 	case 2: st->type = SOCK_DGRAM;
-		if (rand_bool())
+		if (RAND_BOOL())
 			st->protocol = IRDAPROTO_ULTRA;
 		else
 			st->protocol = IRDAPROTO_UNITDATA;
@@ -50,18 +50,13 @@ void irda_rand_socket(struct socket_triplet *st)
 	}
 }
 
-#define NR_SOL_IRDA_OPTS ARRAY_SIZE(irda_opts)
 static const unsigned int irda_opts[] = {
 	IRLMP_ENUMDEVICES, IRLMP_IAS_SET, IRLMP_IAS_QUERY, IRLMP_HINTS_SET,
 	IRLMP_QOS_SET, IRLMP_QOS_GET, IRLMP_MAX_SDU_SIZE, IRLMP_IAS_GET,
-	IRLMP_IAS_DEL, IRLMP_HINT_MASK_SET, IRLMP_WAITDEVICE };
+	IRLMP_IAS_DEL, IRLMP_HINT_MASK_SET, IRLMP_WAITDEVICE
+};
 
 void irda_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
-
-	so->level = SOL_IRDA;
-
-	val = rand() % NR_SOL_IRDA_OPTS;
-	so->optname = irda_opts[val];
+	so->optname = RAND_ARRAY(irda_opts);
 }
