@@ -9,7 +9,7 @@
 #include "config.h"
 #include "net.h"
 #include "random.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
 void llc_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
@@ -34,31 +34,23 @@ void llc_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 void llc_rand_socket(struct socket_triplet *st)
 {
 	st->protocol = rand() % PROTO_MAX;
-	if (rand_bool())
+	if (RAND_BOOL())
 		st->type = SOCK_STREAM;
 	else
 		st->type = SOCK_DGRAM;
 }
 
-#define SOL_LLC 268
-
 #ifndef USE_LLC_OPT_PKTINFO
 #define LLC_OPT_PKTINFO LLC_OPT_UNKNOWN
 #endif
 
-#define NR_SOL_LLC_OPTS ARRAY_SIZE(llc_opts)
 static const unsigned int llc_opts[] = {
 	LLC_OPT_RETRY, LLC_OPT_SIZE, LLC_OPT_ACK_TMR_EXP, LLC_OPT_P_TMR_EXP,
 	LLC_OPT_REJ_TMR_EXP, LLC_OPT_BUSY_TMR_EXP, LLC_OPT_TX_WIN, LLC_OPT_RX_WIN,
-	LLC_OPT_PKTINFO
+	LLC_OPT_PKTINFO,
 };
 
 void llc_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
-
-	so->level = SOL_LLC;
-
-	val = rand() % NR_SOL_LLC_OPTS;
-	so->optname = llc_opts[val];
+	so->optname = RAND_ARRAY(llc_opts);
 }
