@@ -9,7 +9,7 @@
 #include "net.h"
 #include "random.h"
 #include "sanitise.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
 
@@ -31,7 +31,7 @@ void netlink_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 	nl = zmalloc(sizeof(struct sockaddr_nl));
 
 	nl->nl_family = PF_NETLINK;
-	nl->nl_pid = get_pid();
+	nl->nl_pid = rand32();
 	nl->nl_groups = rand32();
 	*addr = (struct sockaddr *) nl;
 	*addrlen = sizeof(struct sockaddr_nl);
@@ -39,7 +39,7 @@ void netlink_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 
 void netlink_rand_socket(struct socket_triplet *st)
 {
-	if (rand_bool())
+	if (RAND_BOOL())
 		st->type = SOCK_RAW;
 	else
 		st->type = SOCK_DGRAM;
@@ -47,20 +47,13 @@ void netlink_rand_socket(struct socket_triplet *st)
 	st->protocol = rand() % (_NETLINK_MAX + 1);
 }
 
-
-#define SOL_NETLINK 270
-
-#define NR_SOL_NETLINK_OPTS ARRAY_SIZE(netlink_opts)
 static const unsigned int netlink_opts[] = {
 	NETLINK_ADD_MEMBERSHIP, NETLINK_DROP_MEMBERSHIP, NETLINK_PKTINFO, NETLINK_BROADCAST_ERROR,
-	NETLINK_NO_ENOBUFS, NETLINK_RX_RING, NETLINK_TX_RING };
+	NETLINK_NO_ENOBUFS, NETLINK_RX_RING, NETLINK_TX_RING, NETLINK_LISTEN_ALL_NSID,
+	NETLINK_LIST_MEMBERSHIPS, NETLINK_CAP_ACK,
+};
 
 void netlink_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
-
-	so->level = SOL_NETLINK;
-
-	val = rand() % NR_SOL_NETLINK_OPTS;
-	so->optname = netlink_opts[val];
+	so->optname = RAND_ARRAY(netlink_opts);
 }
