@@ -7,7 +7,7 @@
 #include <stdlib.h>
 #include "net.h"
 #include "random.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
 void packet_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
@@ -29,7 +29,7 @@ void packet_rand_socket(struct socket_triplet *st)
 {
 	st->protocol = htons(ETH_P_ALL);
 
-	if (rand() % 8 == 0)		// FIXME: 8 ? Why?
+	if (ONE_IN(8))		// FIXME: 8 ? Why?
 		st->protocol = get_random_ether_type();
 
 	switch (rand() % 3) {
@@ -43,25 +43,21 @@ void packet_rand_socket(struct socket_triplet *st)
 	}
 }
 
-#define NR_SOL_PACKET_OPTS ARRAY_SIZE(packet_opts)
 static const unsigned int packet_opts[] = {
 	PACKET_ADD_MEMBERSHIP, PACKET_DROP_MEMBERSHIP, PACKET_RECV_OUTPUT, 4,   /* Value 4 is still used by obsolete turbo-packet. */
 	PACKET_RX_RING, PACKET_STATISTICS, PACKET_COPY_THRESH, PACKET_AUXDATA,
 	PACKET_ORIGDEV, PACKET_VERSION, PACKET_HDRLEN, PACKET_RESERVE,
 	PACKET_TX_RING, PACKET_LOSS, PACKET_VNET_HDR, PACKET_TX_TIMESTAMP,
-	PACKET_TIMESTAMP, PACKET_FANOUT };
+	PACKET_TIMESTAMP, PACKET_FANOUT,
+};
 
 void packet_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
 	char *optval;
 
-	so->level = SOL_PACKET;
-
 	optval = (char *) so->optval;
 
-	val = rand() % NR_SOL_PACKET_OPTS;
-	so->optname = packet_opts[val];
+	so->optname = RAND_ARRAY(packet_opts);
 
 	/* Adjust length according to operation set. */
 	switch (so->optname) {
@@ -72,7 +68,7 @@ void packet_setsockopt(struct sockopt *so)
 	case PACKET_TX_RING:
 	case PACKET_RX_RING:
 #ifdef TPACKET3_HDRLEN
-		if (rand() % 3 == 0)
+		if (ONE_IN(3))
 			so->optlen = sizeof(struct tpacket_req3);
 		else
 #endif
