@@ -26,7 +26,7 @@ void phonet_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 void phonet_rand_socket(struct socket_triplet *st)
 {
 	st->protocol = 0;
-	if (rand_bool())
+	if (RAND_BOOL())
 		st->type = SOCK_DGRAM;
 	else
 		st->type = SOCK_SEQPACKET;
