@@ -11,7 +11,7 @@
 #include <stdlib.h>
 #include "net.h"
 #include "random.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
 void rose_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
@@ -27,7 +27,7 @@ void rose_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 	rose->srose_addr.rose_addr[3] = rand();
 	rose->srose_addr.rose_addr[4] = rand();
 
-	generate_rand_bytes((unsigned char *) rose->srose_call.ax25_call, 7 * 2);
+	generate_rand_bytes((unsigned char *) rose->srose_call.ax25_call, sizeof(ax25_address));
 
 	rose->srose_ndigis = rand();
 
@@ -35,18 +35,13 @@ void rose_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 	*addrlen = sizeof(struct sockaddr_rose);
 }
 
-#define NR_SOL_ROSE_OPTS ARRAY_SIZE(rose_opts)
 static const unsigned int rose_opts[] = {
 	ROSE_DEFER, ROSE_T1, ROSE_T2, ROSE_T3,
-	ROSE_IDLE, ROSE_QBITINCL, ROSE_HOLDBACK };
+	ROSE_IDLE, ROSE_QBITINCL, ROSE_HOLDBACK,
+};
 
 void rose_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
-
-	so->level = SOL_ROSE;
-
-	val = rand() % NR_SOL_ROSE_OPTS;
-	so->optname = rose_opts[val];
+	so->optname = RAND_ARRAY(rose_opts);
 }
 #endif
