@@ -1,11 +1,8 @@
 #include <stdlib.h>
 #include "net.h"
 #include "compat.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 
-#define SOL_SCTP 132
-
-#define NR_SOL_SCTP_OPTS ARRAY_SIZE(sctp_opts)
 static const unsigned int sctp_opts[] = {
 	SCTP_RTOINFO, SCTP_ASSOCINFO, SCTP_INITMSG, SCTP_NODELAY,
 	SCTP_AUTOCLOSE, SCTP_SET_PEER_PRIMARY_ADDR, SCTP_PRIMARY_ADDR, SCTP_ADAPTATION_LAYER,
@@ -17,14 +14,10 @@ static const unsigned int sctp_opts[] = {
 	SCTP_GET_ASSOC_NUMBER, SCTP_GET_ASSOC_ID_LIST, SCTP_AUTO_ASCONF, SCTP_PEER_ADDR_THLDS,
 	SCTP_SOCKOPT_BINDX_ADD, SCTP_SOCKOPT_BINDX_REM, SCTP_SOCKOPT_PEELOFF, SCTP_SOCKOPT_CONNECTX_OLD,
 	SCTP_GET_PEER_ADDRS, SCTP_GET_LOCAL_ADDRS, SCTP_SOCKOPT_CONNECTX, SCTP_SOCKOPT_CONNECTX3,
-	SCTP_GET_ASSOC_STATS };
+	SCTP_GET_ASSOC_STATS,
+};
 
 void sctp_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
-
-	so->level = SOL_SCTP;
-
-	val = rand() % NR_SOL_SCTP_OPTS;
-	so->optname = sctp_opts[val];
+	so->optname = RAND_ARRAY(sctp_opts);
 }
