@@ -6,7 +6,7 @@
 #include <stdlib.h>
 #include "net.h"
 #include "random.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
 void tipc_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
@@ -45,19 +45,14 @@ void tipc_rand_socket(struct socket_triplet *st)
 	}
 }
 
-#define NR_SOL_TIPC_OPTS ARRAY_SIZE(tipc_opts)
 static const unsigned int tipc_opts[] = {
 	TIPC_IMPORTANCE, TIPC_SRC_DROPPABLE, TIPC_DEST_DROPPABLE, TIPC_CONN_TIMEOUT,
-	TIPC_NODE_RECVQ_DEPTH, TIPC_SOCK_RECVQ_DEPTH };
+	TIPC_NODE_RECVQ_DEPTH, TIPC_SOCK_RECVQ_DEPTH,
+};
 
 void tipc_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
-
-	so->level = SOL_TIPC;
-
-	val = rand() % NR_SOL_TIPC_OPTS;
-	so->optname = tipc_opts[val];
+	so->optname = RAND_ARRAY(tipc_opts);
 
 	so->optlen = sizeof(__u32);
 }
