@@ -2,28 +2,25 @@
 #include <netinet/udp.h>
 #include "net.h"
 #include "random.h"
-#include "utils.h"	// ARRAY_SIZE
+#include "utils.h"	// RAND_ARRAY
 #include "compat.h"
 
-#define NR_SOL_UDP_OPTS ARRAY_SIZE(udp_opts)
-static const unsigned int udp_opts[] = { UDP_CORK, UDP_ENCAP };
+static const unsigned int udp_opts[] = {
+	UDP_CORK, UDP_ENCAP
+};
 
 void udp_setsockopt(struct sockopt *so)
 {
-	unsigned char val;
 	char *optval;
 
-	so->level = SOL_UDP;
-
-	val = rand() % NR_SOL_UDP_OPTS;
-	so->optname = udp_opts[val];
+	so->optname = RAND_ARRAY(udp_opts);
 
 	switch (so->optname) {
 	case UDP_CORK:
 		break;
 	case UDP_ENCAP:
 		optval = (char *) so->optval;
-		optval[0] = rand_range(1, 3);        // Encapsulation types.
+		optval[0] = RAND_RANGE(1, 3);        // Encapsulation types.
 		break;
 	default:
 		break;
