@@ -4,22 +4,20 @@
 #include <netinet/in.h>
 #include <linux/dn.h>
 #include <stdlib.h>
-#include "maps.h"
 #include "net.h"
+#include "random.h"
+#include "utils.h"
 
 void unix_gen_sockaddr(struct sockaddr **addr, socklen_t *addrlen)
 {
 	struct sockaddr_un *unixsock;
 	unsigned int len;
 
-	unixsock = malloc(sizeof(struct sockaddr_un));
-	if (unixsock == NULL)
-		return;
+	unixsock = zmalloc(sizeof(struct sockaddr_un));
 
 	unixsock->sun_family = PF_UNIX;
 	len = rand() % 20;
-	memset(&page_rand[len], 0, 1);
-	strncpy(unixsock->sun_path, page_rand, len);
+	generate_rand_bytes((unsigned char *)unixsock->sun_path, len);
 	*addr = (struct sockaddr *) unixsock;
 	*addrlen = sizeof(struct sockaddr_un);
 }
