@@ -32,10 +32,8 @@ void x25_setsockopt(struct sockopt *so)
 {
 	unsigned int *optval;
 
-	so->level = SOL_X25;
-
 	optval = (unsigned int *) so->optval;
-	*optval = rand_bool();
+	*optval = RAND_BOOL();
 
 	so->optlen = sizeof(int);
 }
