@@ -31,7 +31,7 @@ unsigned int user_specified_children = 0;
 bool do_specific_domain = FALSE;
 bool no_domains[TRINITY_PF_MAX];
 
-bool dopause = FALSE;
+bool dry_run = FALSE;
 bool show_syscall_list = FALSE;
 bool show_ioctl_list = FALSE;
 unsigned char quiet_level = 0;
@@ -39,7 +39,6 @@ bool verbose = FALSE;
 bool monochrome = FALSE;
 bool dangerous = FALSE;
 bool dropprivs = FALSE;
-bool logging = TRUE;
 bool do_syslog = FALSE;
 bool random_selection = FALSE;
 unsigned int random_selection_num;
@@ -52,6 +51,8 @@ char *specific_domain_optarg = NULL;
 
 char *victim_path = NULL;
 
+int logging = LOGGING_FILES;
+
 unsigned int kernel_taint_mask = 0xFFFFFFFF;
 bool kernel_taint_param_occured = FALSE;
 
@@ -60,7 +61,7 @@ char server_addr[INET6_ADDRSTRLEN] = "\0";
 
 void enable_disable_fd_usage(void)
 {
-	outputerr(" --enable-fds/--disable-fds= {sockets,pipes,perf,epoll,eventfd,pseudo,timerfd,testfile,memfd}\n");
+	outputerr(" --enable-fds/--disable-fds= {sockets,pipes,perf,epoll,eventfd,pseudo,timerfd,testfile,memfd,drm}\n");
 }
 
 static void usage(void)
@@ -91,12 +92,11 @@ static void usage(void)
 	outputerr("\n");
 	outputerr(" -c#,@: target specific syscall (takes syscall name as parameter and optionally 32 or 64 as bit-width. Default:both).\n");
 	outputerr(" -N#: do # syscalls then exit.\n");
-	outputerr(" -p:  pause after syscall.\n");
 	outputerr(" -s#: use # as random seed.\n");
 	exit(EXIT_SUCCESS);
 }
 
-static const char paramstr[] = "a:b:c:C:dDg:hIl:LN:mP:E:pqr:s:T:SV:vx:X";
+static const char paramstr[] = "a:b:c:C:dDE:g:hIl:LmN:P:qr:s:ST:V:vx:X";
 
 static const struct option longopts[] = {
 	{ "arch", required_argument, NULL, 'a' },
@@ -106,6 +106,7 @@ static const struct option longopts[] = {
 	{ "dropprivs", no_argument, NULL, 'X'},
 	{ "debug", no_argument, NULL, 'D' },
 	{ "disable-fds", required_argument, NULL, 0 },
+	{ "dry-run", no_argument, NULL, 0 },
 	{ "enable-fds", required_argument, NULL, 0 },
 	{ "exclude", required_argument, NULL, 'x' },
 	{ "group", required_argument, NULL, 'g' },
@@ -187,6 +188,10 @@ void parse_args(int argc, char *argv[])
 			set_debug = TRUE;
 			break;
 
+		case 'E':
+			parse_exclude_domains(optarg);
+			break;
+
 		case 'g':
 			if (!strcmp(optarg, "vm"))
 				desired_group = GROUP_VM;
@@ -204,8 +209,8 @@ void parse_args(int argc, char *argv[])
 			break;
 
 		case 'l':
-			if (!strcmp(optarg, "off"))
-				logging = FALSE;
+			if (!strncmp(optarg, "off", 3))
+				logging = LOGGING_DISABLED;
 			break;
 
 		case 'L':
@@ -229,21 +234,12 @@ void parse_args(int argc, char *argv[])
 			syscalls_todo = strtoll(optarg, NULL, 10);
 			break;
 
-		/* Pause after each syscall */
-		case 'p':
-			dopause = TRUE;
-			break;
-
 		case 'P':
 			do_specific_domain = TRUE;
 			specific_domain = strtol(optarg, NULL, 10);
 			specific_domain_optarg = optarg;
 			break;
 
-		case 'E':
-			parse_exclude_domains(optarg);
-			break;
-
 		case 'q':
 			quiet_level++;
 			break;
@@ -322,6 +318,9 @@ void parse_args(int argc, char *argv[])
 			if (strcmp("enable-fds", longopts[opt_index].name) == 0)
 				process_fds_param(optarg, TRUE);
 
+			if (strcmp("dry-run", longopts[opt_index].name) == 0)
+				dry_run = TRUE;
+
 			break;
 		}
 	}
