@@ -3,24 +3,14 @@
 # This is a useful test to run occasionally, to see which syscalls are
 # causing trinity to segfault.
 
-TRINITY_PATH=${TRINITY_PATH:-.}
-TRINITY_TMP=$(mktemp -d /tmp/trinity.XXXXXX)
-
-check_tainted()
-{
-    if [ "$(cat /proc/sys/kernel/tainted)" != $TAINT ]; then
-      echo ERROR: Taint flag changed $(cat /proc/sys/kernel/tainted)
-      exit
-    fi
-}
-
-TAINT=$(cat /proc/sys/kernel/tainted)
+. scripts/paths.sh
+. scripts/privs.sh
+. scripts/taint.sh
 
 while [ 1 ]
 do
 for syscall in $($TRINITY_PATH/trinity -L | grep entrypoint | grep -v AVOID | awk '{ print $3 }' | sort -u)
 do
-	chmod 755 $TRINITY_TMP
 	pushd $TRINITY_TMP
 
 	if [ ! -f $TRINITY_PATH/trinity ]; then
@@ -29,7 +19,9 @@ do
 		exit
 	fi
 
-	MALLOC_CHECK_=2 $TRINITY_PATH/trinity -q -c $syscall -N 99999 -l off -C 64
+	MALLOC_CHECK_=2 $TRINITY_PATH/trinity -q -c $syscall -N 1000000 -l off -C 64 $DROPPRIVS -x execve
+
+	chmod 755 $TRINITY_TMP
 	popd
 
 	check_tainted
