@@ -2,6 +2,7 @@
  * Shared mapping creation.
  */
 
+#include <malloc.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
@@ -19,41 +20,40 @@ struct shm_s *shm;
 
 #define SHM_PROT_PAGES 30
 
+unsigned int shm_size;
+
 void create_shm(void)
 {
-	void *p;
-	void *redbefore, *redafter;
-	unsigned int shm_pages;
-	unsigned int wholesize;
+	unsigned int nr_shm_pages;
 
 	/* round up shm to nearest page size */
-	shm_pages = ((sizeof(struct shm_s) + page_size - 1) & PAGE_MASK) / page_size;
-	wholesize = (SHM_PROT_PAGES + shm_pages + SHM_PROT_PAGES) * page_size;
+	shm_size = (sizeof(struct shm_s) + page_size - 1) & PAGE_MASK;
+	nr_shm_pages = shm_size / page_size;
 
 	/* Waste some address space to set up some "protection" near the SHM location. */
-	p = alloc_shared(wholesize);
-
-	redbefore = p;
-	redafter = p + (SHM_PROT_PAGES + shm_pages) * page_size;
-
-	/* set the redzones. */
-	memset(redbefore, 0x77, SHM_PROT_PAGES * page_size);
-	memset(redafter, 0x88, SHM_PROT_PAGES * page_size);
-
-	/* set the redzones to PROT_NONE */
-	mprotect(redbefore, SHM_PROT_PAGES * page_size, PROT_NONE);
-	mprotect(redafter, SHM_PROT_PAGES * page_size, PROT_NONE);
+	shm = alloc_shared(shm_size);
 
 	/* clear the whole shm. */
-	shm = p + (SHM_PROT_PAGES * page_size);
-	memset(shm, 0, shm_pages * page_size);
-	printf("shm: redzone:%p. shmdata:%p. redzone:%p end:%p.\n",
-		redbefore, shm, redafter, p + wholesize);
+	memset(shm, 0, shm_size);
+	printf("shm:%p-%p (%u pages)\n", shm, shm + shm_size - 1, nr_shm_pages);
+}
+
+void shm_ro(void)
+{
+	if (shm->debug == TRUE)
+		mprotect(shm, shm_size, PROT_READ);
+}
+
+void shm_rw(void)
+{
+	if (shm->debug == TRUE)
+		mprotect(shm, shm_size, PROT_READ|PROT_WRITE);
 }
 
 void init_shm(void)
 {
 	unsigned int i;
+	unsigned int childptrslen;
 
 	output(2, "shm is at %p\n", shm);
 
@@ -69,8 +69,23 @@ void init_shm(void)
 	/* Set seed in parent thread */
 	set_seed(NULL);
 
-	shm->children = zmalloc(max_children * sizeof(struct childdata *));
+	childptrslen = max_children * sizeof(struct childdata *);
+	/* round up to page size */
+	childptrslen += page_size - 1;
+	childptrslen &= PAGE_MASK;
 
+	shm->children = memalign(page_size, childptrslen);
+	if (shm->children == NULL) {
+		printf("Failed to allocate child structures.\n");
+		exit(EXIT_FAILURE);
+	}
+
+	memset(shm->children, 0, childptrslen);
+
+	/* We allocate the childdata structs as shared mappings, because
+	 * the watchdog process needs to peek into each childs syscall records
+	 * to make sure they are making progress.
+	 */
 	for_each_child(i) {
 		struct childdata *child;
 
@@ -84,4 +99,5 @@ void init_shm(void)
 
 		child->logfile = NULL;
 	}
+	mprotect(shm->children, childptrslen, PROT_READ);
 }
