@@ -12,6 +12,7 @@
 
 #include "arch.h"
 #include "child.h"
+#include "params.h"
 #include "pids.h"
 #include "random.h"
 #include "sanitise.h"
@@ -100,10 +101,14 @@ static void __do_syscall(struct syscallrecord *rec)
 
 	errno = 0;
 
-	if (rec->do32bit == FALSE)
-		ret = syscall(call, rec->a1, rec->a2, rec->a3, rec->a4, rec->a5, rec->a6);
-	else
-		ret = syscall32(call, rec->a1, rec->a2, rec->a3, rec->a4, rec->a5, rec->a6);
+	if (dry_run == FALSE) {
+		shm_ro();
+		if (rec->do32bit == FALSE)
+			ret = syscall(call, rec->a1, rec->a2, rec->a3, rec->a4, rec->a5, rec->a6);
+		else
+			ret = syscall32(call, rec->a1, rec->a2, rec->a3, rec->a4, rec->a5, rec->a6);
+		shm_rw();
+	}
 
 	/* We returned! */
 	shm->stats.total_syscalls_done++;
@@ -117,6 +122,11 @@ static void __do_syscall(struct syscallrecord *rec)
 	rec->state = AFTER;
 	unlock(&rec->lock);
 
+	if (IS_ERR(ret))
+		shm->stats.failures++;
+	else
+		shm->stats.successes++;
+
 	if (needalarm)
 		(void)alarm(0);
 }
@@ -140,6 +150,7 @@ static void do_extrafork(struct syscallrecord *rec)
 		__do_syscall(rec);
 		/* if this was for eg. an successful execve, we should never get here.
 		 * if it failed though... */
+		shm->stats.failures++;
 		_exit(EXIT_SUCCESS);
 	}
 
@@ -151,6 +162,7 @@ static void do_extrafork(struct syscallrecord *rec)
 		if (pid_alive(extrapid) == TRUE)
 			kill(extrapid, SIGKILL);
 	}
+	shm->stats.successes++;
 }
 
 
@@ -169,11 +181,6 @@ void do_syscall(struct syscallrecord *rec)
 	else
 		 /* common-case, do the syscall in this child process. */
 		__do_syscall(rec);
-
-	if (IS_ERR(rec->retval))
-		shm->stats.failures++;
-	else
-		shm->stats.successes++;
 }
 
 static void check_retval_documented(struct syscallrecord *rec, struct syscallentry *entry)
@@ -181,6 +188,10 @@ static void check_retval_documented(struct syscallrecord *rec, struct syscallent
 	struct errnos *errnos;
 	unsigned int i;
 
+	/* Just return silently if ENOSYS, we'll disable it immediately afterwards. */
+	if (rec->errno_post == ENOSYS)
+		return;
+
 	/* Only check syscalls we've documented so far. */
 	errnos = &entry->errnos;
 	if (errnos->num == 0)
