@@ -12,7 +12,7 @@
 
 #include "sanitise.h"
 
-struct syscall syscall_fanotify_init = {
+struct syscallentry syscall_fanotify_init = {
 	.name = "fanotify_init",
 	.num_args = 2,
 	.arg1name = "flags",
@@ -24,7 +24,6 @@ struct syscall syscall_fanotify_init = {
 		},
 	},
 	.arg2name = "event_f_flags",
-	.flags = CAPABILITY_CHECK,
 	.rettype = RET_FD,
 	.group = GROUP_VFS,
 };
