@@ -5,13 +5,7 @@
 #include <linux/futex.h>
 #include "sanitise.h"
 
-/*
- * TODO:
- * FUTEX_FD returns ENOSYS as of 2.6.26. Somehow handle this.
- * FUTEX_WAKE_OP also returns ENOSYS
- */
-
-struct syscall syscall_futex = {
+struct syscallentry syscall_futex = {
 	.name = "futex",
 	.num_args = 6,
 	.arg1name = "uaddr",
@@ -33,5 +27,5 @@ struct syscall syscall_futex = {
 	.arg5type = ARG_ADDRESS,
 	.arg6name = "val3",
 	.rettype = RET_FD,		// FIXME: Needs to mutate depending on 'op' value
-	.flags = NEED_ALARM,
+	.flags = NEED_ALARM | IGNORE_ENOSYS,
 };
