@@ -6,7 +6,7 @@
 
 #include <sys/inotify.h>
 
-struct syscall syscall_inotify_add_watch = {
+struct syscallentry syscall_inotify_add_watch = {
 	.name = "inotify_add_watch",
 	.num_args = 3,
 	.arg1name = "fd",
