@@ -3,7 +3,7 @@
  */
 #include "sanitise.h"
 
-struct syscall syscall_inotify_init = {
+struct syscallentry syscall_inotify_init = {
 	.name = "inotify_init",
 	.num_args = 0,
 	.group = GROUP_VFS,
