@@ -10,30 +10,31 @@
 #include "random.h"
 #include "sanitise.h"
 #include "shm.h"
-#include "utils.h"	// page_size
+#include "syscall.h"
+#include "trinity.h"
 
 #define MPOL_F_STATIC_NODES     (1 << 15)
 #define MPOL_F_RELATIVE_NODES   (1 << 14)
 
-static void sanitise_mbind(int childno)
+static void sanitise_mbind(struct syscallrecord *rec)
 {
 	unsigned long maxnode;
 
-	(void) common_set_mmap_ptr_len(childno);
+	(void) common_set_mmap_ptr_len();
 
 retry_maxnode:
-	shm->a5[childno] &= ~((page_size * 8) - 1);
+	rec->a5 &= ~((page_size * 8) - 1);
 
-	maxnode = shm->a5[childno];
+	maxnode = rec->a5;
 
 	if (maxnode < 2 || maxnode > (page_size * 8)) {
-		shm->a5[childno] = rand32();
+		rec->a5 = rand32();
 		goto retry_maxnode;
 	}
 }
 
 
-struct syscall syscall_mbind = {
+struct syscallentry syscall_mbind = {
 	.name = "mbind",
 	.num_args = 6,
 	.arg1name = "start",
@@ -44,8 +45,9 @@ struct syscall syscall_mbind = {
 	.arg3name = "mode",
 	.arg3type = ARG_LIST,
 	.arg3list = {
-		.num = 4,
-		.values = { MPOL_DEFAULT, MPOL_BIND, MPOL_INTERLEAVE, MPOL_PREFERRED },
+		.num = 6,
+		.values = { MPOL_DEFAULT, MPOL_BIND, MPOL_INTERLEAVE, MPOL_PREFERRED,
+			MPOL_F_STATIC_NODES, MPOL_F_RELATIVE_NODES },
 	},
 
 	.arg4name = "nmask",
@@ -59,8 +61,8 @@ struct syscall syscall_mbind = {
 	.arg6name = "flags",
 	.arg6type = ARG_LIST,
 	.arg6list = {
-		.num = 2,
-		.values = { MPOL_F_STATIC_NODES, MPOL_F_RELATIVE_NODES },
+		.num = 3,
+		.values = { MPOL_MF_STRICT, MPOL_MF_MOVE, MPOL_MF_MOVE_ALL, },
 	},
 	.sanitise = sanitise_mbind,
 	.group = GROUP_VM,
