@@ -19,15 +19,54 @@
 #include "trinity.h"
 #include "utils.h"	//ARRAY_SIZE
 
-#ifdef __x86_64__
-#define NUM_FLAGS 13
-#else
-#define NUM_FLAGS 12
-#endif
-
 // need this to actually get MAP_UNINITIALIZED defined
 #define CONFIG_MMAP_ALLOW_UNINITIALIZED
 
+static long sizes[] = {
+	-1,	/* over-written with page_size below */
+	MB(1), MB(2), MB(4), MB(10),
+	GB(1),
+};
+
+static int init_mmap(void)
+{
+	FILE *fp;
+	char *buffer;
+	size_t n = 0;
+
+	if (sizes[0] != -1)
+		return 0;
+
+	sizes[0] = page_size;
+
+	fp = fopen("/proc/meminfo", "r");
+	if (!fp)
+		return -1;
+
+	buffer = malloc(4096);
+	if (!buffer) {
+		fclose(fp);
+		return -1;
+	}
+
+	while (getline(&buffer, &n, fp) >= 0) {
+		unsigned long long free;
+
+		if (sscanf(buffer, "MemFree:         %llu", &free) == 1) {
+			if ((free * 1024) < GB(8ULL)) {
+				printf("Free memory: %.2fGB\n", (double) free / 1024 / 1024);
+				printf("Low on memory, disabling mmaping of 1GB pages\n");
+				sizes[5] = page_size;
+				return 0;
+			}
+		}
+	}
+
+	free(buffer);
+	fclose(fp);
+	return 0;
+}
+
 static void do_anon(struct syscallrecord *rec)
 {
 	/* no fd if anonymous mapping. */
@@ -37,21 +76,14 @@ static void do_anon(struct syscallrecord *rec)
 
 static void sanitise_mmap(struct syscallrecord *rec)
 {
-	unsigned long mmap_flags[NUM_FLAGS] = { MAP_FIXED, MAP_ANONYMOUS,
-			MAP_GROWSDOWN, MAP_DENYWRITE, MAP_EXECUTABLE, MAP_LOCKED,
-			MAP_NORESERVE, MAP_POPULATE, MAP_NONBLOCK, MAP_STACK,
-			MAP_HUGETLB, MAP_UNINITIALIZED,
+	unsigned long mmap_flags[] = {
+		MAP_FIXED, MAP_ANONYMOUS, MAP_GROWSDOWN, MAP_DENYWRITE,
+		MAP_EXECUTABLE, MAP_LOCKED, MAP_NORESERVE, MAP_POPULATE,
+		MAP_NONBLOCK, MAP_STACK, MAP_HUGETLB, MAP_UNINITIALIZED,
 #ifdef __x86_64__
-			MAP_32BIT,
+		MAP_32BIT,
 #endif
 	};
-	unsigned long sizes[] = {
-		-1,	/* over-written with page_size below */
-		1 * MB, 2 * MB, 4 * MB, 10 * MB,
-		1 * GB,
-	};
-
-	sizes[0] = page_size;
 
 	/* Don't actually set a hint right now. */
 	rec->a1 = 0;
@@ -60,7 +92,7 @@ static void sanitise_mmap(struct syscallrecord *rec)
 	rec->a4 = set_rand_bitmask(ARRAY_SIZE(mmap_flags), mmap_flags);
 
 	if (rec->a4 & MAP_ANONYMOUS) {
-		rec->a2 = sizes[rand() % ARRAY_SIZE(sizes)];
+		rec->a2 = RAND_ARRAY(sizes);
 		do_anon(rec);
 	} else {
 		if (this_syscallname("mmap2") == TRUE) {
@@ -99,7 +131,7 @@ static void post_mmap(struct syscallrecord *rec)
 	this_child->num_mappings++;
 
 	/* Sometimes dirty the mapping. */
-	if (rand_bool())
+	if (RAND_BOOL())
 		dirty_mapping(new);
 }
 
@@ -164,6 +196,7 @@ struct syscallentry syscall_mmap = {
 
 	.group = GROUP_VM,
 	.flags = NEED_ALARM,
+	.init = init_mmap,
 };
 
 struct syscallentry syscall_mmap2 = {
@@ -196,4 +229,5 @@ struct syscallentry syscall_mmap2 = {
 
 	.group = GROUP_VM,
 	.flags = NEED_ALARM,
+	.init = init_mmap,
 };
