@@ -2,30 +2,32 @@
  * sys_mprotect(unsigned long start, size_t len, unsigned long prot)
  */
 #include <asm/mman.h>
-#include "utils.h"	// page_size
 #include "arch.h"
 #include "maps.h"
 #include "random.h"
 #include "sanitise.h"
 #include "shm.h"
+#include "syscall.h"
+#include "trinity.h"
+#include "utils.h"
 
-static void sanitise_mprotect(int childno)
+static struct map* map;
+
+static void sanitise_mprotect(__unused__ struct syscallrecord *rec)
 {
-	(void) common_set_mmap_ptr_len(childno);
+	map = common_set_mmap_ptr_len();
 }
 
 /*
  * If we successfully did an mprotect, update our record of the mappings prot bits.
  */
-static void post_mprotect(int childno)
+static void post_mprotect(struct syscallrecord *rec)
 {
-	struct map *map = (struct map *) shm->scratch[childno];
-
-	if (shm->retval[childno] != 0)
-		map->prot = shm->a3[childno];
+	if (rec->retval != 0)
+		map->prot = rec->a3;
 }
 
-struct syscall syscall_mprotect = {
+struct syscallentry syscall_mprotect = {
 	.name = "mprotect",
 	.num_args = 3,
 	.arg1name = "start",
