@@ -18,9 +18,9 @@
 static struct map *map;
 
 static const unsigned long alignments[] = {
-	1 * MB, 2 * MB, 4 * MB, 8 * MB,
-	10 * MB, 100 * MB,
-	1 * GB, 2 * GB, 4 * GB,
+	MB(1), MB(2), MB(4), MB(4),
+	MB(10), MB(100),
+	GB(1), GB(2), GB(4),
 };
 
 static void sanitise_mremap(struct syscallrecord *rec)
@@ -32,10 +32,10 @@ static void sanitise_mremap(struct syscallrecord *rec)
 	rec->a3 = map->size;		//TODO: Munge this.
 
 	if (rec->a4 & MREMAP_FIXED) {
-		unsigned long align = alignments[rand() % ARRAY_SIZE(alignments)];
+		unsigned long align = RAND_ARRAY(alignments);
 		unsigned int shift = (__WORDSIZE / 2) - 1;
 
-		newaddr = rand() % 256;
+		newaddr = RAND_BYTE();
 		newaddr <<= shift;
 		newaddr |= align;
 		newaddr &= ~(align - 1);
@@ -58,7 +58,7 @@ static void post_mremap(struct syscallrecord *rec)
 	map->ptr = ptr;
 
 	/* Sometimes dirty the mapping first. */
-	if (rand_bool())
+	if (RAND_BOOL())
 		dirty_mapping(map);
 }
 
