@@ -6,7 +6,7 @@
 #include "compat.h"
 #include "sanitise.h"
 
-struct syscall syscall_msgrcv = {
+struct syscallentry syscall_msgrcv = {
 	.name = "msgrcv",
 	.num_args = 5,
 	.arg1name = "msqid",
@@ -21,4 +21,5 @@ struct syscall syscall_msgrcv = {
 		.num = 4,
 		.values = { MSG_NOERROR, MSG_EXCEPT, MSG_COPY, IPC_NOWAIT },
 	},
+	.flags = IGNORE_ENOSYS,
 };
