@@ -17,41 +17,36 @@ static struct map *map;
 
 static void sanitise_munmap(struct syscallrecord *rec)
 {
-	unsigned long len;
-	unsigned long nr_pages;
-	unsigned long offset, offsetpagenr;
-
 	map = common_set_mmap_ptr_len();
 
 	action = 0;
 
-	switch (rand() % 20) {
-	case 0:
+	if (ONE_IN(20) == TRUE) {
 		/* delete the whole mapping. */
 		action = WHOLE;
 		return;
+	}
 
-	case 1 ... 10:
+	if (RAND_BOOL()) {
 		/* unmap a range of the mapping. */
+		unsigned long nr_pages;
+		unsigned long offset, offsetpagenr;
+		unsigned long len;
+
 		nr_pages = map->size / page_size;
-		offsetpagenr = (rand() % nr_pages);
+		offsetpagenr = rand() % nr_pages;
 		offset = offsetpagenr * page_size;
 		rec->a1 = (unsigned long) map->ptr + offset;
 
 		len = (rand() % (nr_pages - offsetpagenr)) + 1;
 		len *= page_size;
 		rec->a2 = len;
-		return;
-
-	case 11 ... 19:
+	} else {
 		/* just unmap 1 page of the mapping. */
+
 		rec->a1 = (unsigned long) map->ptr;
 		rec->a1 += (rand() % map->size) & PAGE_MASK;
 		rec->a2 = page_size;
-		return;
-
-	default:
-		break;
 	}
 }
 
@@ -60,8 +55,10 @@ static void post_munmap(struct syscallrecord *rec)
 	if (rec->retval != 0)
 		return;
 
-	if (action == WHOLE)
-		delete_mapping(map);
+	if (action == WHOLE) {
+		list_del(&map->list);
+		this_child->num_mappings--;
+	}
 }
 
 struct syscallentry syscall_munmap = {
