@@ -7,7 +7,7 @@
 #include "sanitise.h"
 #include "compat.h"
 
-struct syscall syscall_name_to_handle_at = {
+struct syscallentry syscall_name_to_handle_at = {
 	.name = "name_to_handle_at",
 	.num_args = 5,
 	.arg1name = "fd",
