@@ -20,6 +20,7 @@
 #include "syscall.h"
 #include "trinity.h"
 #include "compat.h"
+#include <time.h>
 
 #define SYSFS "/sys/bus/event_source/devices/"
 
@@ -562,7 +563,7 @@ static long long random_cache_config(void)
 		cache_id = PERF_COUNT_HW_CACHE_NODE;
 		break;
 	case 7:
-		cache_id = rand() % 256;
+		cache_id = RAND_BYTE();
 		break;
 	default:
 		cache_id = 0;
@@ -580,7 +581,7 @@ static long long random_cache_config(void)
 		hw_cache_op_id = PERF_COUNT_HW_CACHE_OP_PREFETCH;
 		break;
 	case 3:
-		hw_cache_op_id = rand() % 256;
+		hw_cache_op_id = RAND_BYTE();
 		break;
 	default:
 		hw_cache_op_id = 0;
@@ -595,7 +596,7 @@ static long long random_cache_config(void)
 		hw_cache_op_result_id = PERF_COUNT_HW_CACHE_RESULT_MISS;
 		break;
 	case 2:
-		hw_cache_op_result_id = rand() % 256;
+		hw_cache_op_result_id = RAND_BYTE();
 		break;
 	default:
 		hw_cache_op_result_id = 0;
@@ -755,7 +756,7 @@ static long long random_event_config(__u32 *event_type,
 	case PERF_TYPE_BREAKPOINT:
 		/* Breakpoint type only valid if config==0 */
 		/* Set it to something else too anyway     */
-		if (rand_bool())
+		if (RAND_BOOL())
 			config = rand64();
 		else
 			config = 0;
@@ -831,46 +832,46 @@ static long long random_sample_type(void)
 
 	long long sample_type = 0;
 
-	if (rand_bool())
+	if (RAND_BOOL())
 		return rand64();
 
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_IP;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_TID;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_TIME;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_ADDR;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_READ;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_CALLCHAIN;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_ID;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_CPU;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_PERIOD;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_STREAM_ID;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_RAW;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_BRANCH_STACK;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_REGS_USER;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_STACK_USER;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_WEIGHT;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_DATA_SRC;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_IDENTIFIER;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_TRANSACTION;
-	if (rand_bool())
+	if (RAND_BOOL())
 		sample_type |= PERF_SAMPLE_REGS_INTR;
 
 	return sample_type;
@@ -881,16 +882,16 @@ static long long random_read_format(void)
 
 	long long read_format = 0;
 
-	if (rand_bool())
+	if (RAND_BOOL())
 		return rand64();
 
-	if (rand_bool())
+	if (RAND_BOOL())
 		read_format |= PERF_FORMAT_GROUP;
-	if (rand_bool())
+	if (RAND_BOOL())
 		read_format |= PERF_FORMAT_ID;
-	if (rand_bool())
+	if (RAND_BOOL())
 		read_format |= PERF_FORMAT_TOTAL_TIME_ENABLED;
-	if (rand_bool())
+	if (RAND_BOOL())
 		read_format |= PERF_FORMAT_TOTAL_TIME_RUNNING;
 
 	return read_format;
@@ -900,7 +901,7 @@ static int random_attr_size(void) {
 
 	int size=0;
 
-	switch(rand() % 9) {
+	switch(rand() % 10) {
 	case 0:	size = PERF_ATTR_SIZE_VER0;
 		break;
 	case 1: size = PERF_ATTR_SIZE_VER1;
@@ -911,13 +912,15 @@ static int random_attr_size(void) {
 		break;
 	case 4: size = PERF_ATTR_SIZE_VER4;
 		break;
-	case 5: size = sizeof(struct perf_event_attr);
+	case 5: size = PERF_ATTR_SIZE_VER5;
 		break;
-	case 6: size = rand32();
+	case 6: size = sizeof(struct perf_event_attr);
 		break;
-	case 7:	size = get_len();
+	case 7: size = rand32();
 		break;
-	case 8: size = 0;
+	case 8:	size = get_len();
+		break;
+	case 9: size = 0;
 		break;
 	default:
 		break;
@@ -931,33 +934,35 @@ static long long random_branch_sample_type(void)
 
 	long long branch_sample = 0;
 
-	if (rand() % 2)
+	if (RAND_BOOL())
 		return rand64();
 
-	if (rand_bool())
+	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_USER;
-	if (rand_bool())
+	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_KERNEL;
-	if (rand_bool())
+	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_HV;
 
-	if (rand_bool())
+	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_ANY;
-	if (rand_bool())
+	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_ANY_CALL;
-	if (rand_bool())
+	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_ANY_RETURN;
-	if (rand_bool())
+	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_IND_CALL;
-	if (rand_bool())
+	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_COND;
+	if (RAND_BOOL())
+		branch_sample |= PERF_SAMPLE_BRANCH_CALL_STACK;
 
 	/* Transactional Memory Types */
-	if (rand_bool())
+	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_ABORT_TX;
-	if (rand_bool())
+	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_IN_TX;
-	if (rand_bool())
+	if (RAND_BOOL())
 		branch_sample |= PERF_SAMPLE_BRANCH_NO_TX;
 
 	return branch_sample;
@@ -980,32 +985,33 @@ static void create_mostly_valid_counting_event(struct perf_event_attr *attr,
 	attr->read_format = random_read_format();
 
 	/* Bitfield parameters, mostly boolean */
-	attr->disabled = rand_bool();
-	attr->inherit = rand_bool();
+	attr->disabled = RAND_BOOL();
+	attr->inherit = RAND_BOOL();
 	if (group_leader) {
-		attr->pinned = rand_bool();
+		attr->pinned = RAND_BOOL();
 	}
-	attr->exclusive = rand_bool();
-	attr->exclude_user = rand_bool();
-	attr->exclude_kernel = rand_bool();
-	attr->exclude_hv = rand_bool();
-	attr->exclude_idle = rand_bool();
-	attr->mmap = rand_bool();
-	attr->comm = rand_bool();
-	attr->freq = rand_bool();
-	attr->inherit_stat = rand_bool();
-	attr->enable_on_exec = rand_bool();
-	attr->task = rand_bool();
-	attr->watermark = rand_bool();
+	attr->exclusive = RAND_BOOL();
+	attr->exclude_user = RAND_BOOL();
+	attr->exclude_kernel = RAND_BOOL();
+	attr->exclude_hv = RAND_BOOL();
+	attr->exclude_idle = RAND_BOOL();
+	attr->mmap = RAND_BOOL();
+	attr->comm = RAND_BOOL();
+	attr->freq = RAND_BOOL();
+	attr->inherit_stat = RAND_BOOL();
+	attr->enable_on_exec = RAND_BOOL();
+	attr->task = RAND_BOOL();
+	attr->watermark = RAND_BOOL();
 	attr->precise_ip = rand() % 4;	// two bits
-	attr->mmap_data = rand_bool();
-	attr->sample_id_all = rand_bool();
-	attr->exclude_host = rand_bool();
-	attr->exclude_guest = rand_bool();
-	attr->exclude_callchain_kernel = rand_bool();
-	attr->exclude_callchain_user = rand_bool();
-	attr->mmap2 = rand_bool();
-	attr->comm_exec = rand_bool();
+	attr->mmap_data = RAND_BOOL();
+	attr->sample_id_all = RAND_BOOL();
+	attr->exclude_host = RAND_BOOL();
+	attr->exclude_guest = RAND_BOOL();
+	attr->exclude_callchain_kernel = RAND_BOOL();
+	attr->exclude_callchain_user = RAND_BOOL();
+	attr->mmap2 = RAND_BOOL();
+	attr->comm_exec = RAND_BOOL();
+	attr->use_clockid = RAND_BOOL();
 
 	/* wakeup events not relevant */
 
@@ -1040,35 +1046,36 @@ static void create_mostly_valid_sampling_event(struct perf_event_attr *attr,
 	attr->read_format = random_read_format();
 
 	/* Bitfield parameters, mostly boolean */
-	attr->disabled = rand_bool();
-	attr->inherit = rand_bool();
+	attr->disabled = RAND_BOOL();
+	attr->inherit = RAND_BOOL();
 	/* only group leaders can be pinned */
 	if (group_leader) {
-		attr->pinned = rand_bool();
+		attr->pinned = RAND_BOOL();
 	} else {
 		attr->pinned = 0;
 	}
-	attr->exclusive = rand_bool();
-	attr->exclude_user = rand_bool();
-	attr->exclude_kernel = rand_bool();
-	attr->exclude_hv = rand_bool();
-	attr->exclude_idle = rand_bool();
-	attr->mmap = rand_bool();
-	attr->comm = rand_bool();
-	attr->freq = rand_bool();
-	attr->inherit_stat = rand_bool();
-	attr->enable_on_exec = rand_bool();
-	attr->task = rand_bool();
-	attr->watermark = rand_bool();
+	attr->exclusive = RAND_BOOL();
+	attr->exclude_user = RAND_BOOL();
+	attr->exclude_kernel = RAND_BOOL();
+	attr->exclude_hv = RAND_BOOL();
+	attr->exclude_idle = RAND_BOOL();
+	attr->mmap = RAND_BOOL();
+	attr->comm = RAND_BOOL();
+	attr->freq = RAND_BOOL();
+	attr->inherit_stat = RAND_BOOL();
+	attr->enable_on_exec = RAND_BOOL();
+	attr->task = RAND_BOOL();
+	attr->watermark = RAND_BOOL();
 	attr->precise_ip = rand() % 4;	// two bits
-	attr->mmap_data = rand_bool();
-	attr->sample_id_all = rand_bool();
-	attr->exclude_host = rand_bool();
-	attr->exclude_guest = rand_bool();
-	attr->exclude_callchain_kernel = rand_bool();
-	attr->exclude_callchain_user = rand_bool();
-	attr->mmap2 = rand_bool();
-	attr->comm_exec = rand_bool();
+	attr->mmap_data = RAND_BOOL();
+	attr->sample_id_all = RAND_BOOL();
+	attr->exclude_host = RAND_BOOL();
+	attr->exclude_guest = RAND_BOOL();
+	attr->exclude_callchain_kernel = RAND_BOOL();
+	attr->exclude_callchain_user = RAND_BOOL();
+	attr->mmap2 = RAND_BOOL();
+	attr->comm_exec = RAND_BOOL();
+	attr->use_clockid = RAND_BOOL();
 
 	attr->wakeup_events = rand32();
 
@@ -1100,6 +1107,24 @@ static void create_mostly_valid_sampling_event(struct perf_event_attr *attr,
 	/* if we pick too large of a value the kernel in theory truncates */
 	attr->sample_stack_user = rand32();
 
+	if (attr->use_clockid) {
+		switch(rand()%6) {
+			case 0:	attr->clockid = CLOCK_MONOTONIC;
+				break;
+			case 1: attr->clockid = CLOCK_MONOTONIC_RAW;
+				break;
+			case 2: attr->clockid = CLOCK_REALTIME;
+				break;
+			case 3: attr->clockid = CLOCK_BOOTTIME;
+				break;
+			/* Most possible values < 32 */
+			case 4: attr->clockid = RAND_BYTE();
+				break;
+			case 5:	attr->clockid = rand();
+				break;
+		}
+	}
+
 }
 
 
@@ -1122,10 +1147,10 @@ static void create_mostly_valid_global_event(struct perf_event_attr *attr,
 	attr->read_format = random_read_format();
 
 	/* Bitfield parameters, mostly boolean */
-	attr->disabled = rand_bool();
-	attr->inherit = rand_bool();
+	attr->disabled = RAND_BOOL();
+	attr->inherit = RAND_BOOL();
 	if (group_leader) {
-		attr->pinned = rand_bool();
+		attr->pinned = RAND_BOOL();
 	}
 
 	/* Not setting most other paramaters */
@@ -1149,35 +1174,35 @@ static void create_random_event(struct perf_event_attr *attr)
 	attr->read_format = random_read_format();
 
 	/* bitfields */
-	attr->disabled = rand_bool();
-	attr->inherit = rand_bool();
-	attr->pinned = rand_bool();
-	attr->exclusive = rand_bool();
-	attr->exclude_user = rand_bool();
-	attr->exclude_kernel = rand_bool();
-	attr->exclude_hv = rand_bool();
-	attr->exclude_idle = rand_bool();
-	attr->mmap = rand_bool();
-	attr->comm = rand_bool();
-	attr->freq = rand_bool();
-	attr->inherit_stat = rand_bool();
-	attr->enable_on_exec = rand_bool();
-	attr->task = rand_bool();
-	attr->watermark = rand_bool();
+	attr->disabled = RAND_BOOL();
+	attr->inherit = RAND_BOOL();
+	attr->pinned = RAND_BOOL();
+	attr->exclusive = RAND_BOOL();
+	attr->exclude_user = RAND_BOOL();
+	attr->exclude_kernel = RAND_BOOL();
+	attr->exclude_hv = RAND_BOOL();
+	attr->exclude_idle = RAND_BOOL();
+	attr->mmap = RAND_BOOL();
+	attr->comm = RAND_BOOL();
+	attr->freq = RAND_BOOL();
+	attr->inherit_stat = RAND_BOOL();
+	attr->enable_on_exec = RAND_BOOL();
+	attr->task = RAND_BOOL();
+	attr->watermark = RAND_BOOL();
 	attr->precise_ip = rand() % 4;
-	attr->mmap_data = rand_bool();
-	attr->sample_id_all = rand_bool();
-	attr->exclude_host = rand_bool();
-	attr->exclude_guest = rand_bool();
-	attr->exclude_callchain_kernel = rand_bool();
-	attr->exclude_callchain_user = rand_bool();
-	attr->mmap2 = rand_bool();
-	attr->comm_exec = rand_bool();
+	attr->mmap_data = RAND_BOOL();
+	attr->sample_id_all = RAND_BOOL();
+	attr->exclude_host = RAND_BOOL();
+	attr->exclude_guest = RAND_BOOL();
+	attr->exclude_callchain_kernel = RAND_BOOL();
+	attr->exclude_callchain_user = RAND_BOOL();
+	attr->mmap2 = RAND_BOOL();
+	attr->comm_exec = RAND_BOOL();
 
 	attr->wakeup_events=rand32();
 
 	/* Breakpoints are unioned with the config values */
-	if (rand_bool()) {
+	if (RAND_BOOL()) {
 		setup_breakpoints(attr);
 	}
 	else {
@@ -1207,16 +1232,12 @@ void sanitise_perf_event_open(struct syscallrecord *rec)
 	/* requires ROOT to select specific CPU if pid==-1 (all processes) */
 	/* -1 means all CPUs */
 
-	switch(rand() % 2) {
-	case 0:
+	if (RAND_BOOL()) {
 		/* Any CPU */
 		rec->a3 = -1;
-		break;
-	case 1:
+	} else {
 		/* Default to the get_cpu() value */
 		/* set by ARG_CPU                 */
-	default:
-		break;
 	}
 
 	/* group_fd */
@@ -1243,16 +1264,16 @@ void sanitise_perf_event_open(struct syscallrecord *rec)
 	/* flags */
 	/* You almost never set these unless you're playing with cgroups */
 	flags = 0;
-	if (rand_bool()) {
+	if (RAND_BOOL()) {
 		flags = rand64();
 	} else {
-		if (rand_bool())
+		if (RAND_BOOL())
 			flags |= PERF_FLAG_FD_NO_GROUP;
-		if (rand_bool())
+		if (RAND_BOOL())
 			flags |= PERF_FLAG_FD_OUTPUT;
-		if (rand_bool())
+		if (RAND_BOOL())
 			flags |= PERF_FLAG_PID_CGROUP;
-		if (rand_bool())
+		if (RAND_BOOL())
 			flags |= PERF_FLAG_FD_CLOEXEC;
 	}
 	rec->a5 = flags;
