@@ -33,6 +33,10 @@ static int prctl_opts[] = {
 	PR_SET_MM, PR_SET_CHILD_SUBREAPER, PR_GET_CHILD_SUBREAPER, PR_SET_NO_NEW_PRIVS,
 	PR_GET_NO_NEW_PRIVS, PR_GET_TID_ADDRESS, PR_SET_THP_DISABLE, PR_GET_THP_DISABLE,
 	PR_MPX_ENABLE_MANAGEMENT, PR_MPX_DISABLE_MANAGEMENT,
+#ifdef __mips__
+	GET_FP_MODE, SET_FP_MODE,
+#endif
+	PR_CAP_AMBIENT,
 };
 #define NR_PRCTL_OPTS ARRAY_SIZE(prctl_opts)
 
