@@ -3,7 +3,7 @@
  */
 #include "sanitise.h"
 
-struct syscall syscall_rt_sigreturn = {
+struct syscallentry syscall_rt_sigreturn = {
 	.name = "rt_sigreturn",
 	.num_args = 1,
 	.flags = AVOID_SYSCALL, // Confuses the signal state and causes the fuzzer to hang with timeout not firing
