@@ -19,35 +19,56 @@
 #include "compat.h"
 
 struct socket_ptr {
-	unsigned int family;
 	void (*func)(struct socket_triplet *st);
 };
+
 static const struct socket_ptr socketptrs[] = {
+	[AF_UNIX] = { .func = &unix_rand_socket },
+	[AF_INET] = { .func = &inet_rand_socket },
+	[AF_AX25] = { .func = &ax25_rand_socket },
+	[AF_IPX] = { .func = &ipx_rand_socket },
 #ifdef USE_APPLETALK
-	{ .family = AF_APPLETALK, .func = &atalk_rand_socket },
+	[AF_APPLETALK] = { .func = &atalk_rand_socket },
 #endif
-	{ .family = AF_AX25, .func = &ax25_rand_socket },
-#ifdef USE_CAIF
-	{ .family = AF_CAIF, .func = &caif_rand_socket },
-#endif
-	{ .family = AF_CAN, .func = &can_rand_socket },
-	{ .family = AF_DECnet, .func = &decnet_rand_socket },
-	{ .family = AF_INET, .func = &inet_rand_socket },
+	[AF_NETROM] = { .func = NULL },
+	[AF_BRIDGE] = { .func = NULL },
+	[AF_ATMPVC] = { .func = NULL },
+	[AF_X25] = { .func = &x25_rand_socket },
 #ifdef USE_IPV6
-	{ .family = AF_INET6, .func = &inet6_rand_socket },
+	[AF_INET6] = { .func = &inet6_rand_socket },
 #endif
-	{ .family = AF_IPX, .func = &ipx_rand_socket },
-	{ .family = AF_IRDA, .func = &irda_rand_socket },
-	{ .family = AF_LLC, .func = &llc_rand_socket },
-	{ .family = AF_NETLINK, .func = &netlink_rand_socket },
-	{ .family = AF_NFC, .func = &nfc_rand_socket },
-//TODO	{ .family = AF_IB, .func = &ib_rand_socket },
-	{ .family = AF_PACKET, .func = &packet_rand_socket },
-	{ .family = AF_PHONET, .func = &phonet_rand_socket },
-	{ .family = AF_RDS, .func = &rds_rand_socket },
-	{ .family = AF_TIPC, .func = &tipc_rand_socket },
-	{ .family = AF_UNIX, .func = &unix_rand_socket },
-	{ .family = AF_X25, .func = &x25_rand_socket },
+	[AF_ROSE] = { .func = NULL },
+	[AF_DECnet] = { .func = &decnet_rand_socket },
+	[AF_NETBEUI] = { .func = NULL },
+	[AF_SECURITY] = { .func = NULL },
+	[AF_KEY] = { .func = NULL },
+	[AF_NETLINK] = { .func = &netlink_rand_socket },
+	[AF_PACKET] = { .func = &packet_rand_socket },
+	[AF_ASH] = { .func = NULL },
+	[AF_ECONET] = { .func = NULL },	// DEAD
+	[AF_ATMSVC] = { .func = NULL },
+	[AF_RDS] = { .func = &rds_rand_socket },
+	[AF_SNA] = { .func = NULL },
+	[AF_IRDA] = { .func = &irda_rand_socket },
+	[AF_PPPOX] = { .func = NULL },
+	[AF_WANPIPE] = { .func = NULL },
+	[AF_LLC] = { .func = &llc_rand_socket },
+	[AF_IB] = { .func = NULL },
+	[AF_MPLS] = { .func = NULL },
+	[AF_CAN] = { .func = &can_rand_socket },
+	[AF_TIPC] = { .func = &tipc_rand_socket },
+	[AF_BLUETOOTH] = { .func = NULL },
+	[AF_IUCV] = { .func = NULL },
+	[AF_RXRPC] = { .func = NULL },
+	[AF_ISDN] = { .func = NULL },
+	[AF_PHONET] = { .func = NULL },
+	[AF_IEEE802154] = { .func = NULL },
+#ifdef USE_CAIF
+	[AF_CAIF] = { .func = &caif_rand_socket },
+#endif
+	[AF_ALG] = { .func = NULL },
+	[AF_NFC] = { .func = &nfc_rand_socket },
+	[AF_VSOCK] = { .func = NULL },
 };
 
 void rand_proto_type(struct socket_triplet *st)
@@ -85,11 +106,12 @@ void rand_proto_type(struct socket_triplet *st)
 int sanitise_socket_triplet(struct socket_triplet *st)
 {
 	unsigned int i;
-	for (i = 0; i < ARRAY_SIZE(socketptrs); i++) {
-		if (socketptrs[i].family == st->family) {
-			socketptrs[i].func(st);
-			return 0;
-		}
+
+	i = st->family;
+
+	if (socketptrs[i].func != NULL) {
+		socketptrs[i].func(st);
+		return 0;
 	}
 
 	/* Couldn't find func, fall back to random. */
@@ -120,7 +142,7 @@ void gen_socket_args(struct socket_triplet *st)
 	}
 
 	/* sometimes, still gen rand crap */
-	if ((rand() % 100) == 0) {
+	if (ONE_IN(100)) {
 		rand_proto_type(st);
 		goto done;
 	}
@@ -131,9 +153,9 @@ void gen_socket_args(struct socket_triplet *st)
 
 
 done:
-	if ((rand() % 100) < 25)
+	if (ONE_IN(4))
 		st->type |= SOCK_CLOEXEC;
-	if ((rand() % 100) < 25)
+	if (ONE_IN(4))
 		st->type |= SOCK_NONBLOCK;
 }
 
