@@ -3,7 +3,7 @@
  */
 #include "sanitise.h"
 
-struct syscall syscall_sync = {
+struct syscallentry syscall_sync = {
 	.name = "sync",
 	.num_args = 0,
 	.group = GROUP_VFS,
