@@ -3,7 +3,7 @@
  */
 #include "sanitise.h"
 
-struct syscall syscall_vfork = {
+struct syscallentry syscall_vfork = {
 	.name = "vfork",
 	.num_args = 1,
 	.flags = AVOID_SYSCALL, // No args, confuses fuzzer
