@@ -3,7 +3,7 @@
  */
 #include "sanitise.h"
 
-struct syscall syscall_vhangup = {
+struct syscallentry syscall_vhangup = {
 	.name = "vhangup",
 	.num_args = 0,
 	.flags = AVOID_SYSCALL, // No args, confuses fuzzer
