@@ -8,15 +8,17 @@
 #include <stdlib.h>
 #include "sanitise.h"
 #include "shm.h"
+#include "syscall.h"
+#include "trinity.h"
 
-static void sanitise_vmsplice(int childno)
+static void sanitise_vmsplice(struct syscallrecord *rec)
 {
 	if ((rand() % 10) > 0)
-		shm->a1[childno] = shm->pipe_fds[rand() % MAX_PIPE_FDS];
-	shm->a3[childno] = rand() % UIO_MAXIOV;
+		rec->a1 = shm->pipe_fds[rand() % MAX_PIPE_FDS];
+	rec->a3 = rand() % UIO_MAXIOV;
 }
 
-struct syscall syscall_vmsplice = {
+struct syscallentry syscall_vmsplice = {
 	.name = "vmsplice",
 	.num_args = 4,
 	.sanitise = sanitise_vmsplice,
