@@ -124,10 +124,42 @@ void deactivate_syscall(unsigned int call, bool do32bit)
 void count_syscalls_enabled(void)
 {
 	if (biarch == TRUE) {
-		output(0, "32-bit syscalls: %d enabled, %d disabled.  "
-			"64-bit syscalls: %d enabled, %d disabled.\n",
-			shm->nr_active_32bit_syscalls, max_nr_32bit_syscalls - shm->nr_active_32bit_syscalls,
-			shm->nr_active_64bit_syscalls, max_nr_64bit_syscalls - shm->nr_active_64bit_syscalls);
+		char str32[40];
+		char str64[40];
+		unsigned int nr;
+
+		memset(str32, 0, sizeof(str32));
+		memset(str64, 0, sizeof(str64));
+
+		/* first the 32bit syscalls */
+		if (shm->nr_active_32bit_syscalls != 0) {
+			char *p = str32;
+
+			p += sprintf(p, "%d enabled", shm->nr_active_32bit_syscalls);
+
+			nr = max_nr_32bit_syscalls - shm->nr_active_32bit_syscalls;
+			if (nr != 0)
+				p += sprintf(p, ", %u disabled", nr);
+		} else {
+			sprintf(str32, "all disabled.");
+		}
+
+		/* now the 64bit syscalls. */
+		if (shm->nr_active_64bit_syscalls != 0) {
+			char *p = str64;
+
+			p += sprintf(p, "%d enabled", shm->nr_active_64bit_syscalls);
+
+			nr = max_nr_64bit_syscalls - shm->nr_active_64bit_syscalls;
+			if (nr != 0)
+				p += sprintf(p, ", %u disabled", nr);
+		} else {
+			sprintf(str64, "all disabled");
+		}
+
+		output(0, "32-bit syscalls: %s.  64-bit syscalls: %s.\n",
+			str32, str64);
+
 	} else {
 		output(0, "Enabled %d syscalls. Disabled %d syscalls.\n",
 			shm->nr_active_syscalls, max_nr_syscalls - shm->nr_active_syscalls);
@@ -450,15 +482,27 @@ void enable_random_syscalls(void)
 	}
 }
 
+/* By default, all syscall entries will be disabled.
+ * If we didn't pass -c, -x, -r, or -g then mark all syscalls active.
+ */
+static void decide_if_active(void)
+{
+	if (do_specific_syscall == TRUE)
+		return;
+	if (do_exclude_syscall == TRUE)
+		return;
+	if (random_selection == TRUE)
+		return;
+	if (desired_group != GROUP_NONE)
+		return;
+
+	mark_all_syscalls_active();
+}
 
 /* This is run *after* we've parsed params */
 int munge_tables(void)
 {
-	/* By default, all syscall entries will be disabled.
-	 * If we didn't pass -c, -x or -r, mark all syscalls active.
-	 */
-	if ((do_specific_syscall == FALSE) && (do_exclude_syscall == FALSE) && (random_selection == FALSE) && (desired_group == GROUP_NONE))
-		mark_all_syscalls_active();
+	decide_if_active();
 
 	if (desired_group != GROUP_NONE) {
 		unsigned int ret;
