@@ -28,6 +28,7 @@ char *progname = NULL;
 
 unsigned int page_size;
 unsigned int num_online_cpus;
+bool no_bind_to_cpu;
 unsigned int max_children;
 
 /*
@@ -55,6 +56,40 @@ static void change_tmp_dir(void)
 		output(0, "Couldn't change to %s\n", tmpdir);
 }
 
+static int set_exit_code(enum exit_reasons reason)
+{
+	int ret = EXIT_SUCCESS;
+
+	switch (reason) {
+	case EXIT_NO_SYSCALLS_ENABLED:
+	case EXIT_NO_FDS:
+	case EXIT_LOST_CHILD:
+	case EXIT_PID_OUT_OF_RANGE:
+	case EXIT_KERNEL_TAINTED:
+	case EXIT_SHM_CORRUPTION:
+	case EXIT_REPARENT_PROBLEM:
+	case EXIT_NO_FILES:
+	case EXIT_MAIN_DISAPPEARED:
+	case EXIT_UID_CHANGED:
+	case EXIT_LOCKING_CATASTROPHE:
+	case EXIT_FORK_FAILURE:
+	case EXIT_FD_INIT_FAILURE:
+	case EXIT_LOGFILE_OPEN_ERROR:
+		ret = EXIT_FAILURE;
+		break;
+
+	default:
+	/* the next are just to shut up -Werror=switch-enum
+	 * pragma's are just as ugly imo. */
+	case STILL_RUNNING:
+	case EXIT_REACHED_COUNT:
+	case EXIT_SIGINT:
+	case NUM_EXIT_REASONS:
+		break;
+	}
+	return ret;
+}
+
 int main(int argc, char* argv[])
 {
 	int ret = EXIT_SUCCESS;
@@ -72,6 +107,9 @@ int main(int argc, char* argv[])
 	num_online_cpus = sysconf(_SC_NPROCESSORS_ONLN);
 	max_children = num_online_cpus;	/* possibly overridden in params. */
 
+	if (init_random() == FALSE)
+		exit(EXIT_FAILURE);
+
 	set_seed(0);
 
 	select_syscall_tables();
@@ -89,8 +127,7 @@ int main(int argc, char* argv[])
 
 	change_tmp_dir();
 
-	if (logging == TRUE)
-		open_main_logfile();
+	init_logging();
 
 	init_shm();
 
@@ -142,6 +179,8 @@ int main(int argc, char* argv[])
 
 		setup_main_signals();
 
+		no_bind_to_cpu = RAND_BOOL();
+
 		output(0, "Main thread is alive.\n");
 		prctl(PR_SET_NAME, (unsigned long) &taskname);
 		set_seed(0);
@@ -177,9 +216,9 @@ cleanup_fds:
 
 	destroy_initial_mappings();
 
-	if (logging == TRUE)
-		close_logfile(&mainlogfile);
+	shutdown_logging();
 
+	ret = set_exit_code(shm->exit_reason);
 out:
 
 	exit(ret);
