@@ -17,6 +17,7 @@
 #include "files.h"
 #include "locks.h"
 #include "log.h"
+#include "random.h"
 #include "params.h"	// quiet_level
 #include "pids.h"
 #include "post-mortem.h"
@@ -41,11 +42,8 @@ static int shm_is_corrupt(void)
 {
 	unsigned int i;
 
-	// FIXME: The '500000' is magic, and should be dynamically calculated.
-	// On startup, we should figure out how many getpid()'s per second we can do,
-	// and use that.
-	if (shm->stats.total_syscalls_done - shm->stats.previous_op_count > 500000) {
-		output(0, "Execcount increased dramatically! (old:%ld new:%ld):\n",
+	if (shm->stats.total_syscalls_done < shm->stats.previous_op_count) {
+		output(0, "Execcount went backwards! (old:%ld new:%ld):\n",
 			shm->stats.previous_op_count, shm->stats.total_syscalls_done);
 		panic(EXIT_SHM_CORRUPTION);
 		return TRUE;
@@ -242,13 +240,16 @@ unsigned int check_if_fd(struct childdata *child, struct syscallrecord *rec)
 	if (fd > 1024)
 		return FALSE;
 
-	if (child->logfile == NULL)
-		return FALSE;
+	if (logging == LOGGING_FILES) {
+		if (child->logfile == NULL)
+			return FALSE;
 
-	if (fd <= (unsigned int) fileno(child->logfile))
-		return FALSE;
+		if (fd <= (unsigned int) fileno(child->logfile))
+			return FALSE;
+		return TRUE;
+	}
 
-	return TRUE;
+	return FALSE;
 }
 
 static void stuck_syscall_info(struct childdata *child)
@@ -290,7 +291,7 @@ static void stuck_syscall_info(struct childdata *child)
  * recorded before making its last syscall.
  * If no progress is being made, send SIGKILLs to it.
  */
-static void check_child_progress(struct childdata *child)
+static bool is_child_making_progress(struct childdata *child)
 {
 	struct syscallrecord *rec;
 	struct timeval tv;
@@ -300,14 +301,15 @@ static void check_child_progress(struct childdata *child)
 	pid = child->pid;
 
 	if (pid == EMPTY_PIDSLOT)
-		return;
+		return TRUE;
 
 	rec = &child->syscall;
 
 	old = rec->tv.tv_sec;
 
+	/* haven't done anything yet. */
 	if (old == 0)
-		return;
+		return TRUE;
 
 	gettimeofday(&tv, NULL);
 	now = tv.tv_sec;
@@ -319,7 +321,7 @@ static void check_child_progress(struct childdata *child)
 
 	/* hopefully the common case. */
 	if (diff < 30)
-		return;
+		return TRUE;
 
 	/* After 30 seconds of no progress, send a kill signal. */
 	if (diff == 30) {
@@ -332,18 +334,38 @@ static void check_child_progress(struct childdata *child)
 
 	/* if we're still around after 40s, repeatedly send SIGKILLs every second. */
 	if (diff < 40)
-		return;
+		return FALSE;
 
 	debugf("sending another SIGKILL to child %d (pid %u). [kill count:%d] [diff:%d]\n",
 		child->num, pid, child->kill_count, diff);
 	child->kill_count++;
 	kill_pid(pid);
 
-	/* if we wrapped, just reset it, we'll pick it up next time around. */
-	if (diff > 2146) {	/* max adjtime offset, + the 1 second since last time. */
-		output(1, "child %u wrapped! old=%lu now=%lu\n", child->num, old, now);
-		rec->tv.tv_sec = now;
-		return;
+	return FALSE;
+}
+
+/*
+ * If we call this, all children are stalled. Randomly kill a few.
+ */
+static void stall_genocide(void)
+{
+	unsigned int killed = 0;
+	unsigned int i;
+
+	//TODO: We should temporarily stop forking new children too.
+
+	for_each_child(i) {
+		struct childdata *child = shm->children[i];
+
+		if (RAND_BOOL()) {
+			int ret;
+
+			ret = kill(child->pid, SIGKILL);
+			if (ret == 0)
+				killed++;
+		}
+		if (killed == (max_children / 4))
+			break;
 	}
 }
 
@@ -354,9 +376,28 @@ static void watchdog(void)
 	bool watchdog_exit = FALSE;
 
 	while (shm->ready == FALSE) {
-		usleep(1);
-		if (shm->exit_reason != STILL_RUNNING)
-			return;
+		unsigned int counter = 0;
+
+		if (shm->mainpid != 0) {
+			if (check_main_alive() == FALSE)
+				return;
+		}
+
+		while (shm->mainpid == 0) {
+
+			if (check_main_alive() == FALSE)
+				counter++;
+
+			if (counter == 1000) {
+				output(0, "Can't find main at %d\n", shm->mainpid);
+				return;
+			}
+
+			if (shm->exit_reason != STILL_RUNNING)
+				return;
+
+			sleep(1);
+		}
 	}
 
 	output(0, "Watchdog is alive. (pid:%d)\n", watchdog_pid);
@@ -368,6 +409,7 @@ static void watchdog(void)
 
 		int ret = 0;
 		unsigned int i;
+		unsigned int stall_count = 0;
 
 		if (shm_is_corrupt() == TRUE)
 			goto corrupt;
@@ -388,18 +430,27 @@ static void watchdog(void)
 			struct childdata *child = shm->children[i];
 			struct syscallrecord *rec = &child->syscall;
 
-			check_child_progress(child);
+			if (is_child_making_progress(child) == FALSE)
+				stall_count++;
 
 			if (rec->op_nr > hiscore)
 				hiscore = rec->op_nr;
 		}
 
+		if (stall_count == shm->running_childs)
+			stall_genocide();
+
 		if (shm->stats.total_syscalls_done > 1) {
 			if (shm->stats.total_syscalls_done - lastcount > 10000) {
-				output(0, "%ld iterations. [F:%ld S:%ld HI:%ld]\n",
+				char stalltxt[]=" STALLED:XXXX";
+
+				if (stall_count > 0)
+					sprintf(stalltxt, " STALLED:%u", stall_count);
+				output(0, "%ld iterations. [F:%ld S:%ld HI:%ld%s]\n",
 					shm->stats.total_syscalls_done,
 					shm->stats.failures, shm->stats.successes,
-					hiscore);
+					hiscore,
+					stall_count ? stalltxt : "");
 				lastcount = shm->stats.total_syscalls_done;
 			}
 		}
@@ -448,7 +499,10 @@ void init_watchdog(void)
 	pid = fork();
 
 	if (pid == 0) {
+		__unused__ int ret = nice(-20);
+
 		watchdog_pid = getpid();
+
 		watchdog();
 		output(0, "[%d] Watchdog exiting because %s.\n",
 			watchdog_pid, decode_exit());
